import collections.abc
import nanobind
import pydrake.common
import pydrake.math
import pydrake.symbolic
from _typeshed import Incomplete
from pydrake.common.cpp_template import DeterministicVector as DeterministicVector, GaussianVector as GaussianVector, UniformVector as UniformVector
from typing import ClassVar, overload

GetDeterministicValue: nanobind.nb_func
IsDeterministic: nanobind.nb_func
Mean: nanobind.nb_func
Sample: nanobind.nb_func
ToDistribution: nanobind.nb_func
ToDistributionVector: nanobind.nb_func
ToSymbolic: nanobind.nb_func

class Deterministic(Distribution):
    value: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: Deterministic) -> None: ...
    @overload
    def __init__(self, value: float) -> None: ...
    def __copy__(self) -> Deterministic: ...
    def __deepcopy__(self, arg: dict) -> Deterministic: ...
    @property
    def __fields__(self): ...

class DeterministicVectorX(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    value: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: DeterministicVectorTNoneU) -> None: ...
    @overload
    def __init__(self, value) -> None: ...
    def __copy__(self) -> DeterministicVectorTNoneU: ...
    def __deepcopy__(self, arg: dict) -> DeterministicVectorTNoneU: ...
    @property
    def __fields__(self): ...

class DeterministicVector𝓣1𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    value: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: DeterministicVectorT1U) -> None: ...
    @overload
    def __init__(self, value) -> None: ...
    def __copy__(self) -> DeterministicVectorT1U: ...
    def __deepcopy__(self, arg: dict) -> DeterministicVectorT1U: ...
    @property
    def __fields__(self): ...

class DeterministicVector𝓣2𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    value: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: DeterministicVectorT2U) -> None: ...
    @overload
    def __init__(self, value) -> None: ...
    def __copy__(self) -> DeterministicVectorT2U: ...
    def __deepcopy__(self, arg: dict) -> DeterministicVectorT2U: ...
    @property
    def __fields__(self): ...

class DeterministicVector𝓣3𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    value: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: DeterministicVectorT3U) -> None: ...
    @overload
    def __init__(self, value) -> None: ...
    def __copy__(self) -> DeterministicVectorT3U: ...
    def __deepcopy__(self, arg: dict) -> DeterministicVectorT3U: ...
    @property
    def __fields__(self): ...

class DeterministicVector𝓣4𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    value: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: DeterministicVectorT4U) -> None: ...
    @overload
    def __init__(self, value) -> None: ...
    def __copy__(self) -> DeterministicVectorT4U: ...
    def __deepcopy__(self, arg: dict) -> DeterministicVectorT4U: ...
    @property
    def __fields__(self): ...

class DeterministicVector𝓣5𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    value: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: DeterministicVectorT5U) -> None: ...
    @overload
    def __init__(self, value) -> None: ...
    def __copy__(self) -> DeterministicVectorT5U: ...
    def __deepcopy__(self, arg: dict) -> DeterministicVectorT5U: ...
    @property
    def __fields__(self): ...

class DeterministicVector𝓣6𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    value: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: DeterministicVectorT6U) -> None: ...
    @overload
    def __init__(self, value) -> None: ...
    def __copy__(self) -> DeterministicVectorT6U: ...
    def __deepcopy__(self, arg: dict) -> DeterministicVectorT6U: ...
    @property
    def __fields__(self): ...

class DeterministicVector𝓣None𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    value: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: DeterministicVectorTNoneU) -> None: ...
    @overload
    def __init__(self, value) -> None: ...
    def __copy__(self) -> DeterministicVectorTNoneU: ...
    def __deepcopy__(self, arg: dict) -> DeterministicVectorTNoneU: ...
    @property
    def __fields__(self): ...

class Distribution:
    def __init__(self, *args, **kwargs) -> None: ...
    def Mean(self) -> float: ...
    def Sample(self, generator: pydrake.common.RandomGenerator) -> float: ...
    def ToSymbolic(self) -> pydrake.symbolic.Expression: ...

class DistributionVector:
    def __init__(self, *args, **kwargs) -> None: ...
    def Mean(self, *args, **kwargs): ...
    def Sample(self, *args, **kwargs): ...
    def ToSymbolic(self, *args, **kwargs): ...

class Gaussian(Distribution):
    mean: Incomplete
    stddev: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: Gaussian) -> None: ...
    @overload
    def __init__(self, mean: float, stddev: float) -> None: ...
    def __copy__(self) -> Gaussian: ...
    def __deepcopy__(self, arg: dict) -> Gaussian: ...
    @property
    def __fields__(self): ...

class GaussianVectorX(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    mean: Incomplete
    stddev: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: GaussianVectorTNoneU) -> None: ...
    @overload
    def __init__(self, mean, stddev) -> None: ...
    def __copy__(self) -> GaussianVectorTNoneU: ...
    def __deepcopy__(self, arg: dict) -> GaussianVectorTNoneU: ...
    @property
    def __fields__(self): ...

class GaussianVector𝓣1𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    mean: Incomplete
    stddev: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: GaussianVectorT1U) -> None: ...
    @overload
    def __init__(self, mean, stddev) -> None: ...
    def __copy__(self) -> GaussianVectorT1U: ...
    def __deepcopy__(self, arg: dict) -> GaussianVectorT1U: ...
    @property
    def __fields__(self): ...

class GaussianVector𝓣2𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    mean: Incomplete
    stddev: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: GaussianVectorT2U) -> None: ...
    @overload
    def __init__(self, mean, stddev) -> None: ...
    def __copy__(self) -> GaussianVectorT2U: ...
    def __deepcopy__(self, arg: dict) -> GaussianVectorT2U: ...
    @property
    def __fields__(self): ...

class GaussianVector𝓣3𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    mean: Incomplete
    stddev: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: GaussianVectorT3U) -> None: ...
    @overload
    def __init__(self, mean, stddev) -> None: ...
    def __copy__(self) -> GaussianVectorT3U: ...
    def __deepcopy__(self, arg: dict) -> GaussianVectorT3U: ...
    @property
    def __fields__(self): ...

class GaussianVector𝓣4𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    mean: Incomplete
    stddev: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: GaussianVectorT4U) -> None: ...
    @overload
    def __init__(self, mean, stddev) -> None: ...
    def __copy__(self) -> GaussianVectorT4U: ...
    def __deepcopy__(self, arg: dict) -> GaussianVectorT4U: ...
    @property
    def __fields__(self): ...

class GaussianVector𝓣5𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    mean: Incomplete
    stddev: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: GaussianVectorT5U) -> None: ...
    @overload
    def __init__(self, mean, stddev) -> None: ...
    def __copy__(self) -> GaussianVectorT5U: ...
    def __deepcopy__(self, arg: dict) -> GaussianVectorT5U: ...
    @property
    def __fields__(self): ...

class GaussianVector𝓣6𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    mean: Incomplete
    stddev: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: GaussianVectorT6U) -> None: ...
    @overload
    def __init__(self, mean, stddev) -> None: ...
    def __copy__(self) -> GaussianVectorT6U: ...
    def __deepcopy__(self, arg: dict) -> GaussianVectorT6U: ...
    @property
    def __fields__(self): ...

class GaussianVector𝓣None𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    mean: Incomplete
    stddev: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: GaussianVectorTNoneU) -> None: ...
    @overload
    def __init__(self, mean, stddev) -> None: ...
    def __copy__(self) -> GaussianVectorTNoneU: ...
    def __deepcopy__(self, arg: dict) -> GaussianVectorTNoneU: ...
    @property
    def __fields__(self): ...

class Rotation:
    class AngleAxis:
        angle_deg: Incomplete
        axis: Incomplete
        @overload
        def __init__(self, other: Rotation.AngleAxis) -> None: ...
        @overload
        def __init__(self, **kwargs) -> None: ...
        def __copy__(self) -> Rotation.AngleAxis: ...
        def __deepcopy__(self, arg: dict) -> Rotation.AngleAxis: ...
        @property
        def __fields__(self): ...

    class Identity:
        @overload
        def __init__(self, other: Rotation.Identity) -> None: ...
        @overload
        def __init__(self, **kwargs) -> None: ...
        def __copy__(self) -> Rotation.Identity: ...
        def __deepcopy__(self, arg: dict) -> Rotation.Identity: ...
        @property
        def __fields__(self): ...

    class Rpy:
        deg: Incomplete
        @overload
        def __init__(self, other: Rotation.Rpy) -> None: ...
        @overload
        def __init__(self, **kwargs) -> None: ...
        def __copy__(self) -> Rotation.Rpy: ...
        def __deepcopy__(self, arg: dict) -> Rotation.Rpy: ...
        @property
        def __fields__(self): ...

    class Uniform:
        @overload
        def __init__(self, other: Rotation.Uniform) -> None: ...
        @overload
        def __init__(self, **kwargs) -> None: ...
        def __copy__(self) -> Rotation.Uniform: ...
        def __deepcopy__(self, arg: dict) -> Rotation.Uniform: ...
        @property
        def __fields__(self): ...
    value: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: Rotation) -> None: ...
    @overload
    def __init__(self, arg: pydrake.math.RotationMatrix) -> None: ...
    @overload
    def __init__(self, **kwargs) -> None: ...
    def GetDeterministicValue(self) -> pydrake.math.RotationMatrix: ...
    def IsDeterministic(self) -> bool: ...
    def ToSymbolic(self) -> pydrake.math.RotationMatrix_TExpressionU: ...
    def set_rpy_deg(self, rpy_deg) -> None: ...
    def __copy__(self) -> Rotation: ...
    def __deepcopy__(self, arg: dict) -> Rotation: ...
    def __getattr__(self, arg: str) -> object: ...
    def __setattr__(self, arg0: str, arg1: object) -> None: ...
    @property
    def __fields__(self): ...

class Transform:
    _rewrite_yaml_dump_attr_name: ClassVar[nanobind.nb_func] = ...
    base_frame: Incomplete
    rotation: Rotation
    translation: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: Transform) -> None: ...
    @overload
    def __init__(self, arg: pydrake.math.RigidTransform) -> None: ...
    @overload
    def __init__(self, **kwargs) -> None: ...
    def GetDeterministicValue(self) -> pydrake.math.RigidTransform: ...
    def IsDeterministic(self) -> bool: ...
    def Mean(self) -> pydrake.math.RigidTransform: ...
    def Sample(self, generator: pydrake.common.RandomGenerator) -> pydrake.math.RigidTransform: ...
    def ToSymbolic(self) -> pydrake.math.RigidTransform_TExpressionU: ...
    def set_rotation_rpy_deg(self, rpy_deg) -> None: ...
    def __copy__(self) -> Transform: ...
    def __deepcopy__(self, arg: dict) -> Transform: ...
    @property
    def __fields__(self): ...

class Uniform(Distribution):
    max: Incomplete
    min: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: Uniform) -> None: ...
    @overload
    def __init__(self, min: float, max: float) -> None: ...
    def __copy__(self) -> Uniform: ...
    def __deepcopy__(self, arg: dict) -> Uniform: ...
    @property
    def __fields__(self): ...

class UniformDiscrete(Distribution):
    values: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: UniformDiscrete) -> None: ...
    @overload
    def __init__(self, values: collections.abc.Sequence[float]) -> None: ...
    def __copy__(self) -> UniformDiscrete: ...
    def __deepcopy__(self, arg: dict) -> UniformDiscrete: ...
    @property
    def __fields__(self): ...

class UniformVectorX(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    max: Incomplete
    min: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: UniformVectorTNoneU) -> None: ...
    @overload
    def __init__(self, min, max) -> None: ...
    def __copy__(self) -> UniformVectorTNoneU: ...
    def __deepcopy__(self, arg: dict) -> UniformVectorTNoneU: ...
    @property
    def __fields__(self): ...

class UniformVector𝓣1𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    max: Incomplete
    min: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: UniformVectorT1U) -> None: ...
    @overload
    def __init__(self, min, max) -> None: ...
    def __copy__(self) -> UniformVectorT1U: ...
    def __deepcopy__(self, arg: dict) -> UniformVectorT1U: ...
    @property
    def __fields__(self): ...

class UniformVector𝓣2𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    max: Incomplete
    min: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: UniformVectorT2U) -> None: ...
    @overload
    def __init__(self, min, max) -> None: ...
    def __copy__(self) -> UniformVectorT2U: ...
    def __deepcopy__(self, arg: dict) -> UniformVectorT2U: ...
    @property
    def __fields__(self): ...

class UniformVector𝓣3𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    max: Incomplete
    min: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: UniformVectorT3U) -> None: ...
    @overload
    def __init__(self, min, max) -> None: ...
    def __copy__(self) -> UniformVectorT3U: ...
    def __deepcopy__(self, arg: dict) -> UniformVectorT3U: ...
    @property
    def __fields__(self): ...

class UniformVector𝓣4𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    max: Incomplete
    min: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: UniformVectorT4U) -> None: ...
    @overload
    def __init__(self, min, max) -> None: ...
    def __copy__(self) -> UniformVectorT4U: ...
    def __deepcopy__(self, arg: dict) -> UniformVectorT4U: ...
    @property
    def __fields__(self): ...

class UniformVector𝓣5𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    max: Incomplete
    min: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: UniformVectorT5U) -> None: ...
    @overload
    def __init__(self, min, max) -> None: ...
    def __copy__(self) -> UniformVectorT5U: ...
    def __deepcopy__(self, arg: dict) -> UniformVectorT5U: ...
    @property
    def __fields__(self): ...

class UniformVector𝓣6𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    max: Incomplete
    min: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: UniformVectorT6U) -> None: ...
    @overload
    def __init__(self, min, max) -> None: ...
    def __copy__(self) -> UniformVectorT6U: ...
    def __deepcopy__(self, arg: dict) -> UniformVectorT6U: ...
    @property
    def __fields__(self): ...

class UniformVector𝓣None𝓤(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    max: Incomplete
    min: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: UniformVectorTNoneU) -> None: ...
    @overload
    def __init__(self, min, max) -> None: ...
    def __copy__(self) -> UniformVectorTNoneU: ...
    def __deepcopy__(self, arg: dict) -> UniformVectorTNoneU: ...
    @property
    def __fields__(self): ...

class _InvalidVariantSelectionDeterministic:
    def __init__(self, *args, **kwargs) -> None: ...

class _InvalidVariantSelectionGaussian:
    def __init__(self, *args, **kwargs) -> None: ...

class _InvalidVariantSelectionUniform:
    def __init__(self, *args, **kwargs) -> None: ...

class _TemporaryName_N5drake6schema13UniformVectorILi1EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    max: Incomplete
    min: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: UniformVectorT1U) -> None: ...
    @overload
    def __init__(self, min, max) -> None: ...
    def __copy__(self) -> UniformVectorT1U: ...
    def __deepcopy__(self, arg: dict) -> UniformVectorT1U: ...
    @property
    def __fields__(self): ...

class _TemporaryName_N5drake6schema13UniformVectorILi2EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    max: Incomplete
    min: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: UniformVectorT2U) -> None: ...
    @overload
    def __init__(self, min, max) -> None: ...
    def __copy__(self) -> UniformVectorT2U: ...
    def __deepcopy__(self, arg: dict) -> UniformVectorT2U: ...
    @property
    def __fields__(self): ...

class _TemporaryName_N5drake6schema13UniformVectorILi3EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    max: Incomplete
    min: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: UniformVectorT3U) -> None: ...
    @overload
    def __init__(self, min, max) -> None: ...
    def __copy__(self) -> UniformVectorT3U: ...
    def __deepcopy__(self, arg: dict) -> UniformVectorT3U: ...
    @property
    def __fields__(self): ...

class _TemporaryName_N5drake6schema13UniformVectorILi4EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    max: Incomplete
    min: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: UniformVectorT4U) -> None: ...
    @overload
    def __init__(self, min, max) -> None: ...
    def __copy__(self) -> UniformVectorT4U: ...
    def __deepcopy__(self, arg: dict) -> UniformVectorT4U: ...
    @property
    def __fields__(self): ...

class _TemporaryName_N5drake6schema13UniformVectorILi5EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    max: Incomplete
    min: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: UniformVectorT5U) -> None: ...
    @overload
    def __init__(self, min, max) -> None: ...
    def __copy__(self) -> UniformVectorT5U: ...
    def __deepcopy__(self, arg: dict) -> UniformVectorT5U: ...
    @property
    def __fields__(self): ...

class _TemporaryName_N5drake6schema13UniformVectorILi6EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    max: Incomplete
    min: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: UniformVectorT6U) -> None: ...
    @overload
    def __init__(self, min, max) -> None: ...
    def __copy__(self) -> UniformVectorT6U: ...
    def __deepcopy__(self, arg: dict) -> UniformVectorT6U: ...
    @property
    def __fields__(self): ...

class _TemporaryName_N5drake6schema13UniformVectorILin1EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    max: Incomplete
    min: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: UniformVectorTNoneU) -> None: ...
    @overload
    def __init__(self, min, max) -> None: ...
    def __copy__(self) -> UniformVectorTNoneU: ...
    def __deepcopy__(self, arg: dict) -> UniformVectorTNoneU: ...
    @property
    def __fields__(self): ...

class _TemporaryName_N5drake6schema14GaussianVectorILi1EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    mean: Incomplete
    stddev: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: GaussianVectorT1U) -> None: ...
    @overload
    def __init__(self, mean, stddev) -> None: ...
    def __copy__(self) -> GaussianVectorT1U: ...
    def __deepcopy__(self, arg: dict) -> GaussianVectorT1U: ...
    @property
    def __fields__(self): ...

class _TemporaryName_N5drake6schema14GaussianVectorILi2EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    mean: Incomplete
    stddev: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: GaussianVectorT2U) -> None: ...
    @overload
    def __init__(self, mean, stddev) -> None: ...
    def __copy__(self) -> GaussianVectorT2U: ...
    def __deepcopy__(self, arg: dict) -> GaussianVectorT2U: ...
    @property
    def __fields__(self): ...

class _TemporaryName_N5drake6schema14GaussianVectorILi3EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    mean: Incomplete
    stddev: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: GaussianVectorT3U) -> None: ...
    @overload
    def __init__(self, mean, stddev) -> None: ...
    def __copy__(self) -> GaussianVectorT3U: ...
    def __deepcopy__(self, arg: dict) -> GaussianVectorT3U: ...
    @property
    def __fields__(self): ...

class _TemporaryName_N5drake6schema14GaussianVectorILi4EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    mean: Incomplete
    stddev: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: GaussianVectorT4U) -> None: ...
    @overload
    def __init__(self, mean, stddev) -> None: ...
    def __copy__(self) -> GaussianVectorT4U: ...
    def __deepcopy__(self, arg: dict) -> GaussianVectorT4U: ...
    @property
    def __fields__(self): ...

class _TemporaryName_N5drake6schema14GaussianVectorILi5EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    mean: Incomplete
    stddev: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: GaussianVectorT5U) -> None: ...
    @overload
    def __init__(self, mean, stddev) -> None: ...
    def __copy__(self) -> GaussianVectorT5U: ...
    def __deepcopy__(self, arg: dict) -> GaussianVectorT5U: ...
    @property
    def __fields__(self): ...

class _TemporaryName_N5drake6schema14GaussianVectorILi6EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    mean: Incomplete
    stddev: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: GaussianVectorT6U) -> None: ...
    @overload
    def __init__(self, mean, stddev) -> None: ...
    def __copy__(self) -> GaussianVectorT6U: ...
    def __deepcopy__(self, arg: dict) -> GaussianVectorT6U: ...
    @property
    def __fields__(self): ...

class _TemporaryName_N5drake6schema14GaussianVectorILin1EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    mean: Incomplete
    stddev: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: GaussianVectorTNoneU) -> None: ...
    @overload
    def __init__(self, mean, stddev) -> None: ...
    def __copy__(self) -> GaussianVectorTNoneU: ...
    def __deepcopy__(self, arg: dict) -> GaussianVectorTNoneU: ...
    @property
    def __fields__(self): ...

class _TemporaryName_N5drake6schema19DeterministicVectorILi1EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    value: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: DeterministicVectorT1U) -> None: ...
    @overload
    def __init__(self, value) -> None: ...
    def __copy__(self) -> DeterministicVectorT1U: ...
    def __deepcopy__(self, arg: dict) -> DeterministicVectorT1U: ...
    @property
    def __fields__(self): ...

class _TemporaryName_N5drake6schema19DeterministicVectorILi2EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    value: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: DeterministicVectorT2U) -> None: ...
    @overload
    def __init__(self, value) -> None: ...
    def __copy__(self) -> DeterministicVectorT2U: ...
    def __deepcopy__(self, arg: dict) -> DeterministicVectorT2U: ...
    @property
    def __fields__(self): ...

class _TemporaryName_N5drake6schema19DeterministicVectorILi3EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    value: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: DeterministicVectorT3U) -> None: ...
    @overload
    def __init__(self, value) -> None: ...
    def __copy__(self) -> DeterministicVectorT3U: ...
    def __deepcopy__(self, arg: dict) -> DeterministicVectorT3U: ...
    @property
    def __fields__(self): ...

class _TemporaryName_N5drake6schema19DeterministicVectorILi4EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    value: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: DeterministicVectorT4U) -> None: ...
    @overload
    def __init__(self, value) -> None: ...
    def __copy__(self) -> DeterministicVectorT4U: ...
    def __deepcopy__(self, arg: dict) -> DeterministicVectorT4U: ...
    @property
    def __fields__(self): ...

class _TemporaryName_N5drake6schema19DeterministicVectorILi5EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    value: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: DeterministicVectorT5U) -> None: ...
    @overload
    def __init__(self, value) -> None: ...
    def __copy__(self) -> DeterministicVectorT5U: ...
    def __deepcopy__(self, arg: dict) -> DeterministicVectorT5U: ...
    @property
    def __fields__(self): ...

class _TemporaryName_N5drake6schema19DeterministicVectorILi6EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    value: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: DeterministicVectorT6U) -> None: ...
    @overload
    def __init__(self, value) -> None: ...
    def __copy__(self) -> DeterministicVectorT6U: ...
    def __deepcopy__(self, arg: dict) -> DeterministicVectorT6U: ...
    @property
    def __fields__(self): ...

class _TemporaryName_N5drake6schema19DeterministicVectorILin1EEE(DistributionVector):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    value: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: DeterministicVectorTNoneU) -> None: ...
    @overload
    def __init__(self, value) -> None: ...
    def __copy__(self) -> DeterministicVectorTNoneU: ...
    def __deepcopy__(self, arg: dict) -> DeterministicVectorTNoneU: ...
    @property
    def __fields__(self): ...



import gymnasium as gym
import numpy as np

from pydrake.common import FindResourceOrThrow
from pydrake.common.cpp_param import List
from pydrake.common.value import Value
from pydrake.examples.gym.named_view_helpers import (
    MakeNamedViewActuation,
    MakeNamedViewPositions,
    MakeNamedViewState,
)
from pydrake.geometry import (
    ClippingRange,
    ColorRenderCamera,
    DepthRange,
    DepthRenderCamera,
    MakeRenderEngineVtk,
    MeshcatVisualizer,
    RenderCameraCore,
    RenderEngineVtkParams,
)
from pydrake.gym import DrakeGymEnv
from pydrake.math import RigidTransform, RollPitchYaw
from pydrake.multibody.math import SpatialForce
from pydrake.multibody.parsing import Parser
from pydrake.multibody.plant import (
    AddMultibodyPlant,
    ExternallyAppliedSpatialForce_,
    MultibodyPlant,
    MultibodyPlantConfig,
)
from pydrake.multibody.tree import (
    PrismaticJoint,
    RevoluteJoint,
)
from pydrake.systems.analysis import Simulator
from pydrake.systems.drawing import plot_graphviz, plot_system_graphviz
from pydrake.systems.framework import (
    DiagramBuilder,
    EventStatus,
    LeafSystem,
)
from pydrake.systems.primitives import (
    ConstantVectorSource,
    Multiplexer,
    PassThrough,
)
from pydrake.systems.sensors import CameraInfo, RgbdSensor

# Gym parameters.
sim_time_step = 0.01
gym_time_step = 0.05
controller_time_step = 0.01
gym_time_limit = 5
contact_model = "point"
discrete_contact_approximation = "lagged"


def AddAgent(plant=None, builder=None):
    parser = Parser(builder=builder, plant=plant)
    model_file = FindResourceOrThrow(
        "drake/bindings/pydrake/examples/gym/models/cartpole_BSA.sdf"
    )
    (agent,) = parser.AddModels(model_file)
    return agent


def make_sim(
    meshcat=None,
    time_limit=5,
    debug=False,
    obs_noise=False,
    monitoring_camera=False,
    add_disturbances=False,
):
    builder = DiagramBuilder()

    multibody_plant_config = MultibodyPlantConfig(
        time_step=sim_time_step,
        contact_model=contact_model,
        discrete_contact_approximation=discrete_contact_approximation,
    )

    plant, scene_graph = AddMultibodyPlant(multibody_plant_config, builder)

    # Add assets to the plant.
    agent = AddAgent(builder=builder)
    plant.Finalize()
    plant.set_name("plant")

    # Add assets to the controller plant.
    controller_plant = MultibodyPlant(time_step=controller_time_step)
    AddAgent(plant=controller_plant)

    if meshcat:
        MeshcatVisualizer.AddToBuilder(builder, scene_graph, meshcat)

    # Finalize the plant.
    controller_plant.Finalize()
    controller_plant.set_name("controller_plant")

    # Extract the controller plant information.
    ns = controller_plant.num_multibody_states()
    nv = controller_plant.num_velocities()
    na = controller_plant.num_actuators()
    nj = controller_plant.num_joints()
    npos = controller_plant.num_positions()

    # Make NamedViews
    state_view = MakeNamedViewState(controller_plant, "States")
    position_view = MakeNamedViewPositions(controller_plant, "Position")
    actuation_view = MakeNamedViewActuation(controller_plant, "Actuation")

    if debug:
        print(
            f"\nNumber of position: {npos},",
            f"Number of velocities: {nv},",
            f"Number of actuators: {na},",
            f"Number of joints: {nj},",
            f"Number of multibody states: {ns}",
        )
        print("State view: ", state_view(np.ones(ns)))
        print("Position view: ", position_view(np.ones(npos)))
        print("Actuation view: ", actuation_view(np.ones(na)), "\n")

        # Visualize the plant.
        import matplotlib.pyplot as plt

        plt.figure()
        plot_graphviz(plant.GetTopologyGraphvizString())
        plt.plot(1)
        plt.show(block=False)

    # Actions are positions sent to plant.
    actuation = builder.AddSystem(Multiplexer([1, 1]))
    prismatic_actuation_force = builder.AddSystem(PassThrough(1))
    # Zero torque to the revolute joint --it is underactuated.
    revolute_actuation_torque = builder.AddSystem(ConstantVectorSource([0]))
    builder.Connect(
        revolute_actuation_torque.get_output_port(), actuation.get_input_port(1)
    )
    builder.Connect(
        prismatic_actuation_force.get_output_port(), actuation.get_input_port(0)
    )
    builder.Connect(
        actuation.get_output_port(), plant.get_actuation_input_port(agent)
    )
    builder.ExportInput(prismatic_actuation_force.get_input_port(), "actions")

    class ObservationPublisher(LeafSystem):
        def __init__(self, noise=False):
            LeafSystem.__init__(self)
            self.ns = plant.num_multibody_states()
            self.DeclareVectorInputPort("plant_states", self.ns)
            self.DeclareVectorOutputPort("observations", self.ns, self.CalcObs)
            self.noise = noise

        def CalcObs(self, context, output):
            plant_state = self.get_input_port(0).Eval(context)
            if self.noise:
                plant_state += np.random.uniform(
                    low=-0.01, high=0.01, size=self.ns
                )
            output.set_value(plant_state)

    obs_pub = builder.AddSystem(ObservationPublisher(noise=obs_noise))

    builder.Connect(plant.get_state_output_port(), obs_pub.get_input_port(0))
    builder.ExportOutput(obs_pub.get_output_port(), "observations")

    class RewardSystem(LeafSystem):
        def __init__(self):
            LeafSystem.__init__(self)
            # The state port is not used.
            ns = plant.num_multibody_states()
            self.DeclareVectorInputPort("state", ns)
            self.DeclareVectorOutputPort("reward", 1, self.CalcReward)

        def CalcReward(self, context, output):
            reward = 1
            output[0] = reward

    reward = builder.AddSystem(RewardSystem())
    builder.Connect(
        plant.get_state_output_port(agent), reward.get_input_port(0)
    )
    builder.ExportOutput(reward.get_output_port(), "reward")

    if monitoring_camera:
        # Adds an overhead camera.
        # This is useful for logging videos of rollout evaluation.
        scene_graph.AddRenderer(
            "renderer", MakeRenderEngineVtk(RenderEngineVtkParams())
        )
        color_camera = ColorRenderCamera(
            RenderCameraCore(
                "renderer",
                CameraInfo(width=640, height=480, fov_y=np.pi / 4),
                ClippingRange(0.01, 10.0),
                RigidTransform(),
            ),
            False,
        )
        depth_camera = DepthRenderCamera(
            color_camera.core(), DepthRange(0.01, 10.0)
        )
        X_PB = RigidTransform(
            RollPitchYaw(-np.pi / 2, 0, 0), np.array([0, -2.5, 0.4])
        )
        rgbd_camera = builder.AddSystem(
            RgbdSensor(
                parent_id=scene_graph.world_frame_id(),
                X_PB=X_PB,
                color_camera=color_camera,
                depth_camera=depth_camera,
            )
        )
        builder.Connect(
            scene_graph.get_query_output_port(),
            rgbd_camera.query_object_input_port(),
        )
        builder.ExportOutput(
            rgbd_camera.color_image_output_port(), "color_image"
        )

    class DisturbanceGenerator(LeafSystem):
        def __init__(self, plant, force_mag, period, duration):
            # Applies a random force [-force_mag, force_mag] at
            # the COM of the Pole body in the x direction every
            # period seconds for a given duration.
            LeafSystem.__init__(self)
            forces_cls = Value[List[ExternallyAppliedSpatialForce_[float]]]
            self.DeclareAbstractOutputPort(
                "spatial_forces", lambda: forces_cls(), self.CalcDisturbances
            )
            self.plant = plant
            self.pole_body = self.plant.GetBodyByName("Pole")
            self.force_mag = force_mag
            assert period > duration, (
                f"period: {period} must be larger than duration: {duration}"
            )
            self.period = period
            self.duration = duration

        def CalcDisturbances(self, context, spatial_forces_vector):
            # Apply a force at COM of the Pole body.
            force = ExternallyAppliedSpatialForce_[float]()
            force.body_index = self.pole_body.index()
            force.p_BoBq_B = self.pole_body.default_com()
            y = context.get_time() % self.period
            if not ((y >= 0) and (y <= (self.period - self.duration))):
                spatial_force = SpatialForce(
                    tau=[0, 0, 0],
                    f=[
                        np.random.uniform(
                            low=-self.force_mag, high=self.force_mag
                        ),
                        0,
                        0,
                    ],
                )
            else:
                spatial_force = SpatialForce(tau=[0, 0, 0], f=[0, 0, 0])
            force.F_Bq_W = spatial_force
            spatial_forces_vector.set_value([force])

    if add_disturbances:
        # Applies a force of 1N every 1s
        # for 0.1s at the COM of the Pole body.
        disturbance_generator = builder.AddSystem(
            DisturbanceGenerator(
                plant=plant, force_mag=1, period=1, duration=0.1
            )
        )
        builder.Connect(
            disturbance_generator.get_output_port(),
            plant.get_applied_spatial_force_input_port(),
        )

    diagram = builder.Build()
    simulator = Simulator(diagram)
    simulator.Initialize()

    def monitor(context, state_view=state_view):
        """
        Monitors the simulation for episode end conditions.
        """
        plant_context = plant.GetMyContextFromRoot(context)
        state = plant.GetOutputPort("state").Eval(plant_context)
        s = state_view(state)

        # Truncation: the episode duration reaches the time limit.
        if context.get_time() > time_limit:
            if debug:
                print("Episode reached time limit.")
            return EventStatus.ReachedTermination(diagram, "time limit")

        # Termination: The pole angle exceeded +-0.2 rad.
        if abs(s.PolePin_q) > 0.2:
            if debug:
                print("Pole angle exceeded +-0.2 rad.")
            return EventStatus.ReachedTermination(
                diagram, "pole angle exceeded +-0.2 rad"
            )

        # Termination: Cart position exceeded +-2.4 m.
        if abs(s.CartSlider_x) > 2.4:
            if debug:
                print("Cart position exceeded +-2.4 m.")
            return EventStatus.ReachedTermination(
                diagram, "cart position exceeded +-2.4 m"
            )

        return EventStatus.Succeeded()

    simulator.set_monitor(monitor)

    if debug:
        # Visualize the controller plant and diagram.
        plt.figure()
        plot_graphviz(controller_plant.GetTopologyGraphvizString())
        plt.figure()
        plot_system_graphviz(diagram, max_depth=2)
        plt.plot(1)
        plt.show(block=False)

    return simulator


def reset_handler(simulator, diagram_context, seed):
    """
    Provides an easy method for domain randomization.
    """

    # Set the seed.
    np.random.seed(seed)

    # Randomize the initial position of the joints.
    home_positions = [
        ("CartSlider", np.random.uniform(low=-0.1, high=0.1)),
        ("PolePin", np.random.uniform(low=-0.15, high=0.15)),
    ]

    # Randomize the initial velocities of the PolePin joint.
    home_velocities = [("PolePin", np.random.uniform(low=-0.1, high=0.1))]

    # Randomize the mass of the Pole by adding a mass offset.
    home_body_mass_offset = [("Pole", np.random.uniform(low=-0.05, high=0.05))]

    diagram = simulator.get_system()
    plant = diagram.GetSubsystemByName("plant")
    plant_context = diagram.GetMutableSubsystemContext(plant, diagram_context)

    # Ensure the positions are within the joint limits.
    for pair in home_positions:
        joint = plant.GetJointByName(pair[0])
        if joint.type_name() == RevoluteJoint.kTypeName:
            joint.set_angle(
                plant_context,
                np.clip(
                    pair[1],
                    joint.position_lower_limit(),
                    joint.position_upper_limit(),
                ),
            )
        if joint.type_name() == PrismaticJoint.kTypeName:
            joint.set_translation(
                plant_context,
                np.clip(
                    pair[1],
                    joint.position_lower_limit(),
                    joint.position_upper_limit(),
                ),
            )
    for pair in home_velocities:
        joint = plant.GetJointByName(pair[0])
        if joint.type_name() == RevoluteJoint.kTypeName:
            joint.set_angular_rate(
                plant_context,
                np.clip(
                    pair[1],
                    joint.velocity_lower_limit(),
                    joint.velocity_upper_limit(),
                ),
            )
    for pair in home_body_mass_offset:
        body = plant.GetBodyByName(pair[0])
        mass = body.get_mass(plant.CreateDefaultContext())
        body.SetMass(plant_context, mass + pair[1])


def info_handler(simulator: Simulator) -> dict:
    info = dict()
    info["timestamp"] = simulator.get_context().get_time()
    return info


def DrakeCartPoleEnv(
    meshcat=None,
    time_limit=gym_time_limit,
    debug=False,
    obs_noise=False,
    monitoring_camera=False,
    add_disturbances=False,
):
    # Make simulation.
    simulator = make_sim(
        meshcat=meshcat,
        time_limit=time_limit,
        debug=debug,
        obs_noise=obs_noise,
        monitoring_camera=monitoring_camera,
        add_disturbances=add_disturbances,
    )

    plant = simulator.get_system().GetSubsystemByName("plant")

    # Define Action space.
    na = 1
    low_a = plant.GetEffortLowerLimits()[:na]
    high_a = plant.GetEffortUpperLimits()[:na]
    action_space = gym.spaces.Box(
        low=np.asarray(low_a, dtype="float32"),
        high=np.asarray(high_a, dtype="float32"),
        dtype=np.float32,
    )

    # Define observation space.
    low = np.concatenate(
        (plant.GetPositionLowerLimits(), plant.GetVelocityLowerLimits())
    )
    high = np.concatenate(
        (plant.GetPositionUpperLimits(), plant.GetVelocityUpperLimits())
    )
    observation_space = gym.spaces.Box(
        low=np.asarray(low), high=np.asarray(high), dtype=np.float64
    )

    env = DrakeGymEnv(
        simulator=simulator,
        time_step=gym_time_step,
        action_space=action_space,
        observation_space=observation_space,
        reward="reward",
        action_port_id="actions",
        observation_port_id="observations",
        reset_handler=reset_handler,
        info_handler=info_handler,
        render_rgb_port_id="color_image" if monitoring_camera else None,
    )

    # Expose parameters that could be useful for learning.
    env.time_step = gym_time_step
    env.sim_time_step = sim_time_step

    return env



import nanobind
import pydrake.autodiffutils
import pydrake.symbolic
from _typeshed import Incomplete
from pydrake.common.cpp_template import AngleAxis_ as AngleAxis_, Isometry3_ as Isometry3_, Quaternion_ as Quaternion_
from typing import Callable, ClassVar, overload

__getattr__: Callable

class AngleAxis:
    Identity: ClassVar[nanobind.nb_func] = ...
    cast𝓣AutoDiffXd𝓤: ClassVar[Callable] = ...
    cast𝓣Expression𝓤: ClassVar[Callable] = ...
    cast𝓣float𝓤: ClassVar[Callable] = ...
    cast: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, angle: float, axis) -> None: ...
    @overload
    def __init__(self, quaternion: Quaternion) -> None: ...
    @overload
    def __init__(self, rotation) -> None: ...
    @overload
    def __init__(self, other: AngleAxis) -> None: ...
    def angle(self) -> float: ...
    def axis(self, *args, **kwargs): ...
    def inverse(self) -> AngleAxis: ...
    def multiply(self, other: AngleAxis) -> Quaternion: ...
    def quaternion(self) -> Quaternion: ...
    def rotation(self, *args, **kwargs): ...
    def set_angle(self, angle: float) -> None: ...
    def set_axis(self, axis) -> None: ...
    def set_quaternion(self, q: Quaternion) -> None: ...
    def set_rotation(self, rotation) -> None: ...
    def __copy__(self) -> AngleAxis: ...
    def __deepcopy__(self, arg: dict) -> AngleAxis: ...
    def __matmul__(self, *args, **kwargs): ...

class AngleAxis_𝓣AutoDiffXd𝓤:
    Identity: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    cast𝓣AutoDiffXd𝓤: ClassVar[Callable] = ...
    cast: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, angle: pydrake.autodiffutils.AutoDiffXd, axis) -> None: ...
    @overload
    def __init__(self, quaternion: Quaternion_TAutoDiffXdU) -> None: ...
    @overload
    def __init__(self, rotation) -> None: ...
    @overload
    def __init__(self, other: AngleAxis_TAutoDiffXdU) -> None: ...
    def angle(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def axis(self, *args, **kwargs): ...
    def inverse(self) -> AngleAxis_TAutoDiffXdU: ...
    def multiply(self, other: AngleAxis_TAutoDiffXdU) -> Quaternion_TAutoDiffXdU: ...
    def quaternion(self) -> Quaternion_TAutoDiffXdU: ...
    def rotation(self, *args, **kwargs): ...
    def set_angle(self, angle: pydrake.autodiffutils.AutoDiffXd) -> None: ...
    def set_axis(self, axis) -> None: ...
    def set_quaternion(self, q: Quaternion_TAutoDiffXdU) -> None: ...
    def set_rotation(self, rotation) -> None: ...
    def __copy__(self) -> AngleAxis_TAutoDiffXdU: ...
    def __deepcopy__(self, arg: dict) -> AngleAxis_TAutoDiffXdU: ...
    def __matmul__(self, *args, **kwargs): ...

class AngleAxis_𝓣Expression𝓤:
    Identity: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    cast𝓣Expression𝓤: ClassVar[Callable] = ...
    cast: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, angle: pydrake.symbolic.Expression, axis) -> None: ...
    @overload
    def __init__(self, quaternion: Quaternion_TExpressionU) -> None: ...
    @overload
    def __init__(self, rotation) -> None: ...
    @overload
    def __init__(self, other: AngleAxis_TExpressionU) -> None: ...
    def angle(self) -> pydrake.symbolic.Expression: ...
    def axis(self, *args, **kwargs): ...
    def inverse(self) -> AngleAxis_TExpressionU: ...
    def multiply(self, other: AngleAxis_TExpressionU) -> Quaternion_TExpressionU: ...
    def quaternion(self) -> Quaternion_TExpressionU: ...
    def rotation(self, *args, **kwargs): ...
    def set_angle(self, angle: pydrake.symbolic.Expression) -> None: ...
    def set_axis(self, axis) -> None: ...
    def set_quaternion(self, q: Quaternion_TExpressionU) -> None: ...
    def set_rotation(self, rotation) -> None: ...
    def __copy__(self) -> AngleAxis_TExpressionU: ...
    def __deepcopy__(self, arg: dict) -> AngleAxis_TExpressionU: ...
    def __matmul__(self, *args, **kwargs): ...

class Isometry3:
    Identity: ClassVar[nanobind.nb_func] = ...
    cast𝓣AutoDiffXd𝓤: ClassVar[Callable] = ...
    cast𝓣Expression𝓤: ClassVar[Callable] = ...
    cast𝓣float𝓤: ClassVar[Callable] = ...
    multiply: ClassVar[Callable] = ...
    __matmul__: ClassVar[Callable] = ...
    cast: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, matrix) -> None: ...
    @overload
    def __init__(self, rotation, translation) -> None: ...
    @overload
    def __init__(self, quaternion: Quaternion, translation) -> None: ...
    @overload
    def __init__(self, other: Isometry3) -> None: ...
    def inverse(self) -> Isometry3: ...
    def matrix(self, *args, **kwargs): ...
    def quaternion(self) -> Quaternion: ...
    def rotation(self, *args, **kwargs): ...
    def set_matrix(self, arg) -> None: ...
    def set_quaternion(self, arg: Quaternion) -> None: ...
    def set_rotation(self, arg) -> None: ...
    def set_translation(self, arg) -> None: ...
    def translation(self, *args, **kwargs): ...
    def __copy__(self) -> Isometry3: ...
    def __deepcopy__(self, arg: dict) -> Isometry3: ...

class Isometry3_𝓣AutoDiffXd𝓤:
    Identity: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    cast𝓣AutoDiffXd𝓤: ClassVar[Callable] = ...
    multiply: ClassVar[Callable] = ...
    __matmul__: ClassVar[Callable] = ...
    cast: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, matrix) -> None: ...
    @overload
    def __init__(self, rotation, translation) -> None: ...
    @overload
    def __init__(self, quaternion: Quaternion_TAutoDiffXdU, translation) -> None: ...
    @overload
    def __init__(self, other: Isometry3_TAutoDiffXdU) -> None: ...
    def inverse(self) -> Isometry3_TAutoDiffXdU: ...
    def matrix(self, *args, **kwargs): ...
    def quaternion(self) -> Quaternion_TAutoDiffXdU: ...
    def rotation(self, *args, **kwargs): ...
    def set_matrix(self, arg) -> None: ...
    def set_quaternion(self, arg: Quaternion_TAutoDiffXdU) -> None: ...
    def set_rotation(self, arg) -> None: ...
    def set_translation(self, arg) -> None: ...
    def translation(self, *args, **kwargs): ...
    def __copy__(self) -> Isometry3_TAutoDiffXdU: ...
    def __deepcopy__(self, arg: dict) -> Isometry3_TAutoDiffXdU: ...

class Isometry3_𝓣Expression𝓤:
    Identity: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    cast𝓣Expression𝓤: ClassVar[Callable] = ...
    multiply: ClassVar[Callable] = ...
    __matmul__: ClassVar[Callable] = ...
    cast: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, matrix) -> None: ...
    @overload
    def __init__(self, rotation, translation) -> None: ...
    @overload
    def __init__(self, quaternion: Quaternion_TExpressionU, translation) -> None: ...
    @overload
    def __init__(self, other: Isometry3_TExpressionU) -> None: ...
    def inverse(self) -> Isometry3_TExpressionU: ...
    def matrix(self, *args, **kwargs): ...
    def quaternion(self) -> Quaternion_TExpressionU: ...
    def rotation(self, *args, **kwargs): ...
    def set_matrix(self, arg) -> None: ...
    def set_quaternion(self, arg: Quaternion_TExpressionU) -> None: ...
    def set_rotation(self, arg) -> None: ...
    def set_translation(self, arg) -> None: ...
    def translation(self, *args, **kwargs): ...
    def __copy__(self) -> Isometry3_TExpressionU: ...
    def __deepcopy__(self, arg: dict) -> Isometry3_TExpressionU: ...

class Quaternion:
    Identity: ClassVar[nanobind.nb_func] = ...
    cast𝓣AutoDiffXd𝓤: ClassVar[Callable] = ...
    cast𝓣Expression𝓤: ClassVar[Callable] = ...
    cast𝓣float𝓤: ClassVar[Callable] = ...
    multiply: ClassVar[Callable] = ...
    __matmul__: ClassVar[Callable] = ...
    cast: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, wxyz) -> None: ...
    @overload
    def __init__(self, w: float, x: float, y: float, z: float) -> None: ...
    @overload
    def __init__(self, rotation) -> None: ...
    @overload
    def __init__(self, other: Quaternion) -> None: ...
    def conjugate(self) -> Quaternion: ...
    def inverse(self) -> Quaternion: ...
    def rotation(self, *args, **kwargs): ...
    def set_rotation(self, arg) -> None: ...
    @overload
    def set_wxyz(self, wxyz) -> None: ...
    @overload
    def set_wxyz(self, w: float, x: float, y: float, z: float) -> None: ...
    def slerp(self, t: float, other: Quaternion) -> Quaternion: ...
    def w(self) -> float: ...
    def wxyz(self, *args, **kwargs): ...
    def x(self) -> float: ...
    def xyz(self, *args, **kwargs): ...
    def y(self) -> float: ...
    def z(self) -> float: ...
    def __copy__(self) -> Quaternion: ...
    def __deepcopy__(self, arg: dict) -> Quaternion: ...

class Quaternion_𝓣AutoDiffXd𝓤:
    Identity: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    cast𝓣AutoDiffXd𝓤: ClassVar[Callable] = ...
    multiply: ClassVar[Callable] = ...
    __matmul__: ClassVar[Callable] = ...
    cast: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, wxyz) -> None: ...
    @overload
    def __init__(self, w: pydrake.autodiffutils.AutoDiffXd, x: pydrake.autodiffutils.AutoDiffXd, y: pydrake.autodiffutils.AutoDiffXd, z: pydrake.autodiffutils.AutoDiffXd) -> None: ...
    @overload
    def __init__(self, rotation) -> None: ...
    @overload
    def __init__(self, other: Quaternion_TAutoDiffXdU) -> None: ...
    def conjugate(self) -> Quaternion_TAutoDiffXdU: ...
    def inverse(self) -> Quaternion_TAutoDiffXdU: ...
    def rotation(self, *args, **kwargs): ...
    def set_rotation(self, arg) -> None: ...
    @overload
    def set_wxyz(self, wxyz) -> None: ...
    @overload
    def set_wxyz(self, w: pydrake.autodiffutils.AutoDiffXd, x: pydrake.autodiffutils.AutoDiffXd, y: pydrake.autodiffutils.AutoDiffXd, z: pydrake.autodiffutils.AutoDiffXd) -> None: ...
    def slerp(self, t: float, other: Quaternion_TAutoDiffXdU) -> Quaternion_TAutoDiffXdU: ...
    def w(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def wxyz(self, *args, **kwargs): ...
    def x(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def xyz(self, *args, **kwargs): ...
    def y(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def z(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def __copy__(self) -> Quaternion_TAutoDiffXdU: ...
    def __deepcopy__(self, arg: dict) -> Quaternion_TAutoDiffXdU: ...

class Quaternion_𝓣Expression𝓤:
    Identity: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    cast𝓣Expression𝓤: ClassVar[Callable] = ...
    multiply: ClassVar[Callable] = ...
    __matmul__: ClassVar[Callable] = ...
    cast: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, wxyz) -> None: ...
    @overload
    def __init__(self, w: pydrake.symbolic.Expression, x: pydrake.symbolic.Expression, y: pydrake.symbolic.Expression, z: pydrake.symbolic.Expression) -> None: ...
    @overload
    def __init__(self, rotation) -> None: ...
    @overload
    def __init__(self, other: Quaternion_TExpressionU) -> None: ...
    def conjugate(self) -> Quaternion_TExpressionU: ...
    def inverse(self) -> Quaternion_TExpressionU: ...
    def rotation(self, *args, **kwargs): ...
    def set_rotation(self, arg) -> None: ...
    @overload
    def set_wxyz(self, wxyz) -> None: ...
    @overload
    def set_wxyz(self, w: pydrake.symbolic.Expression, x: pydrake.symbolic.Expression, y: pydrake.symbolic.Expression, z: pydrake.symbolic.Expression) -> None: ...
    def slerp(self, t: float, other: Quaternion_TExpressionU) -> Quaternion_TExpressionU: ...
    def w(self) -> pydrake.symbolic.Expression: ...
    def wxyz(self, *args, **kwargs): ...
    def x(self) -> pydrake.symbolic.Expression: ...
    def xyz(self, *args, **kwargs): ...
    def y(self) -> pydrake.symbolic.Expression: ...
    def z(self) -> pydrake.symbolic.Expression: ...
    def __copy__(self) -> Quaternion_TExpressionU: ...
    def __deepcopy__(self, arg: dict) -> Quaternion_TExpressionU: ...

class _TemporaryName_N5Eigen10QuaternionIN5drake2ad8AutoDiffELi0EEE:
    Identity: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    cast𝓣AutoDiffXd𝓤: ClassVar[Callable] = ...
    multiply: ClassVar[Callable] = ...
    __matmul__: ClassVar[Callable] = ...
    cast: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, wxyz) -> None: ...
    @overload
    def __init__(self, w: pydrake.autodiffutils.AutoDiffXd, x: pydrake.autodiffutils.AutoDiffXd, y: pydrake.autodiffutils.AutoDiffXd, z: pydrake.autodiffutils.AutoDiffXd) -> None: ...
    @overload
    def __init__(self, rotation) -> None: ...
    @overload
    def __init__(self, other: Quaternion_TAutoDiffXdU) -> None: ...
    def conjugate(self) -> Quaternion_TAutoDiffXdU: ...
    def inverse(self) -> Quaternion_TAutoDiffXdU: ...
    def rotation(self, *args, **kwargs): ...
    def set_rotation(self, arg) -> None: ...
    @overload
    def set_wxyz(self, wxyz) -> None: ...
    @overload
    def set_wxyz(self, w: pydrake.autodiffutils.AutoDiffXd, x: pydrake.autodiffutils.AutoDiffXd, y: pydrake.autodiffutils.AutoDiffXd, z: pydrake.autodiffutils.AutoDiffXd) -> None: ...
    def slerp(self, t: float, other: Quaternion_TAutoDiffXdU) -> Quaternion_TAutoDiffXdU: ...
    def w(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def wxyz(self, *args, **kwargs): ...
    def x(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def xyz(self, *args, **kwargs): ...
    def y(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def z(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def __copy__(self) -> Quaternion_TAutoDiffXdU: ...
    def __deepcopy__(self, arg: dict) -> Quaternion_TAutoDiffXdU: ...

class _TemporaryName_N5Eigen10QuaternionIN5drake8symbolic10ExpressionELi0EEE:
    Identity: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    cast𝓣Expression𝓤: ClassVar[Callable] = ...
    multiply: ClassVar[Callable] = ...
    __matmul__: ClassVar[Callable] = ...
    cast: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, wxyz) -> None: ...
    @overload
    def __init__(self, w: pydrake.symbolic.Expression, x: pydrake.symbolic.Expression, y: pydrake.symbolic.Expression, z: pydrake.symbolic.Expression) -> None: ...
    @overload
    def __init__(self, rotation) -> None: ...
    @overload
    def __init__(self, other: Quaternion_TExpressionU) -> None: ...
    def conjugate(self) -> Quaternion_TExpressionU: ...
    def inverse(self) -> Quaternion_TExpressionU: ...
    def rotation(self, *args, **kwargs): ...
    def set_rotation(self, arg) -> None: ...
    @overload
    def set_wxyz(self, wxyz) -> None: ...
    @overload
    def set_wxyz(self, w: pydrake.symbolic.Expression, x: pydrake.symbolic.Expression, y: pydrake.symbolic.Expression, z: pydrake.symbolic.Expression) -> None: ...
    def slerp(self, t: float, other: Quaternion_TExpressionU) -> Quaternion_TExpressionU: ...
    def w(self) -> pydrake.symbolic.Expression: ...
    def wxyz(self, *args, **kwargs): ...
    def x(self) -> pydrake.symbolic.Expression: ...
    def xyz(self, *args, **kwargs): ...
    def y(self) -> pydrake.symbolic.Expression: ...
    def z(self) -> pydrake.symbolic.Expression: ...
    def __copy__(self) -> Quaternion_TExpressionU: ...
    def __deepcopy__(self, arg: dict) -> Quaternion_TExpressionU: ...

class _TemporaryName_N5Eigen9AngleAxisIN5drake2ad8AutoDiffEEE:
    Identity: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    cast𝓣AutoDiffXd𝓤: ClassVar[Callable] = ...
    cast: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, angle: pydrake.autodiffutils.AutoDiffXd, axis) -> None: ...
    @overload
    def __init__(self, quaternion: Quaternion_TAutoDiffXdU) -> None: ...
    @overload
    def __init__(self, rotation) -> None: ...
    @overload
    def __init__(self, other: AngleAxis_TAutoDiffXdU) -> None: ...
    def angle(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def axis(self, *args, **kwargs): ...
    def inverse(self) -> AngleAxis_TAutoDiffXdU: ...
    def multiply(self, other: AngleAxis_TAutoDiffXdU) -> Quaternion_TAutoDiffXdU: ...
    def quaternion(self) -> Quaternion_TAutoDiffXdU: ...
    def rotation(self, *args, **kwargs): ...
    def set_angle(self, angle: pydrake.autodiffutils.AutoDiffXd) -> None: ...
    def set_axis(self, axis) -> None: ...
    def set_quaternion(self, q: Quaternion_TAutoDiffXdU) -> None: ...
    def set_rotation(self, rotation) -> None: ...
    def __copy__(self) -> AngleAxis_TAutoDiffXdU: ...
    def __deepcopy__(self, arg: dict) -> AngleAxis_TAutoDiffXdU: ...
    def __matmul__(self, *args, **kwargs): ...

class _TemporaryName_N5Eigen9AngleAxisIN5drake8symbolic10ExpressionEEE:
    Identity: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    cast𝓣Expression𝓤: ClassVar[Callable] = ...
    cast: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, angle: pydrake.symbolic.Expression, axis) -> None: ...
    @overload
    def __init__(self, quaternion: Quaternion_TExpressionU) -> None: ...
    @overload
    def __init__(self, rotation) -> None: ...
    @overload
    def __init__(self, other: AngleAxis_TExpressionU) -> None: ...
    def angle(self) -> pydrake.symbolic.Expression: ...
    def axis(self, *args, **kwargs): ...
    def inverse(self) -> AngleAxis_TExpressionU: ...
    def multiply(self, other: AngleAxis_TExpressionU) -> Quaternion_TExpressionU: ...
    def quaternion(self) -> Quaternion_TExpressionU: ...
    def rotation(self, *args, **kwargs): ...
    def set_angle(self, angle: pydrake.symbolic.Expression) -> None: ...
    def set_axis(self, axis) -> None: ...
    def set_quaternion(self, q: Quaternion_TExpressionU) -> None: ...
    def set_rotation(self, rotation) -> None: ...
    def __copy__(self) -> AngleAxis_TExpressionU: ...
    def __deepcopy__(self, arg: dict) -> AngleAxis_TExpressionU: ...
    def __matmul__(self, *args, **kwargs): ...

class _TemporaryName_N5Eigen9TransformIN5drake2ad8AutoDiffELi3ELi1ELi0EEE:
    Identity: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    cast𝓣AutoDiffXd𝓤: ClassVar[Callable] = ...
    multiply: ClassVar[Callable] = ...
    __matmul__: ClassVar[Callable] = ...
    cast: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, matrix) -> None: ...
    @overload
    def __init__(self, rotation, translation) -> None: ...
    @overload
    def __init__(self, quaternion: Quaternion_TAutoDiffXdU, translation) -> None: ...
    @overload
    def __init__(self, other: Isometry3_TAutoDiffXdU) -> None: ...
    def inverse(self) -> Isometry3_TAutoDiffXdU: ...
    def matrix(self, *args, **kwargs): ...
    def quaternion(self) -> Quaternion_TAutoDiffXdU: ...
    def rotation(self, *args, **kwargs): ...
    def set_matrix(self, arg) -> None: ...
    def set_quaternion(self, arg: Quaternion_TAutoDiffXdU) -> None: ...
    def set_rotation(self, arg) -> None: ...
    def set_translation(self, arg) -> None: ...
    def translation(self, *args, **kwargs): ...
    def __copy__(self) -> Isometry3_TAutoDiffXdU: ...
    def __deepcopy__(self, arg: dict) -> Isometry3_TAutoDiffXdU: ...

class _TemporaryName_N5Eigen9TransformIN5drake8symbolic10ExpressionELi3ELi1ELi0EEE:
    Identity: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    cast𝓣Expression𝓤: ClassVar[Callable] = ...
    multiply: ClassVar[Callable] = ...
    __matmul__: ClassVar[Callable] = ...
    cast: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, matrix) -> None: ...
    @overload
    def __init__(self, rotation, translation) -> None: ...
    @overload
    def __init__(self, quaternion: Quaternion_TExpressionU, translation) -> None: ...
    @overload
    def __init__(self, other: Isometry3_TExpressionU) -> None: ...
    def inverse(self) -> Isometry3_TExpressionU: ...
    def matrix(self, *args, **kwargs): ...
    def quaternion(self) -> Quaternion_TExpressionU: ...
    def rotation(self, *args, **kwargs): ...
    def set_matrix(self, arg) -> None: ...
    def set_quaternion(self, arg: Quaternion_TExpressionU) -> None: ...
    def set_rotation(self, arg) -> None: ...
    def set_translation(self, arg) -> None: ...
    def translation(self, *args, **kwargs): ...
    def __copy__(self) -> Isometry3_TExpressionU: ...
    def __deepcopy__(self, arg: dict) -> Isometry3_TExpressionU: ...



import collections.abc
import enum
import nanobind
import pydrake.autodiffutils
import pydrake.common.eigen_geometry
import pydrake.symbolic
import pydrake.symbolic as _sym
from _typeshed import Incomplete
from pydrake.common.cpp_template import BsplineBasis_ as BsplineBasis_, RigidTransform_ as RigidTransform_, RollPitchYaw_ as RollPitchYaw_, RotationMatrix_ as RotationMatrix_
from typing import Callable, ClassVar, overload

AreQuaternionsEqualForOrientation: nanobind.nb_func
BalanceQuadraticForms: nanobind.nb_func
CalculateAngularVelocityExpressedInBFromQuaternionDt: nanobind.nb_func
CalculateQuaternionDtConstraintViolation: nanobind.nb_func
CalculateQuaternionDtFromAngularVelocityExpressedInB: nanobind.nb_func
ClosestQuaternion: nanobind.nb_func
ComputeNumericalGradient: nanobind.nb_func
ContinuousAlgebraicRiccatiEquation: nanobind.nb_func
DecomposePSDmatrixIntoXtransposeTimesX: nanobind.nb_func
DecomposePositiveQuadraticForm: nanobind.nb_func
DiscreteAlgebraicRiccatiEquation: nanobind.nb_func
ExtractPrincipalSubmatrix: nanobind.nb_func
IsBothQuaternionAndQuaternionDtOK: nanobind.nb_func
IsPositiveDefinite: nanobind.nb_func
IsQuaternionValid: nanobind.nb_func
IsSymmetric: nanobind.nb_func
QuaternionToCanonicalForm: nanobind.nb_func
RealContinuousLyapunovEquation: nanobind.nb_func
RealDiscreteLyapunovEquation: nanobind.nb_func
SoftOverMax: nanobind.nb_func
SoftOverMin: nanobind.nb_func
SoftUnderMax: nanobind.nb_func
SoftUnderMin: nanobind.nb_func
ToLowerTriangularColumnsFromMatrix: nanobind.nb_func
ToSymmetricMatrixFromLowerTriangularColumns: nanobind.nb_func
UniformlyRandomAngleAxis: nanobind.nb_func
UniformlyRandomQuaternion: nanobind.nb_func
UniformlyRandomRPY: nanobind.nb_func
UniformlyRandomRotationMatrix: nanobind.nb_func
VectorToSkewSymmetric: nanobind.nb_func
__getattr__: Callable
abs: nanobind.nb_func
acos: nanobind.nb_func
arccos: nanobind.nb_func
arcsin: nanobind.nb_func
arctan: nanobind.nb_func
arctan2: nanobind.nb_func
asin: nanobind.nb_func
atan: nanobind.nb_func
atan2: nanobind.nb_func
ceil: nanobind.nb_func
cos: nanobind.nb_func
cosh: nanobind.nb_func
exp: nanobind.nb_func
floor: nanobind.nb_func
inv: nanobind.nb_func
is_quaternion_in_canonical_form: nanobind.nb_func
isnan: nanobind.nb_func
log: nanobind.nb_func
matmul: nanobind.nb_func
max: nanobind.nb_func
min: nanobind.nb_func
pow: nanobind.nb_func
sin: nanobind.nb_func
sinh: nanobind.nb_func
sqrt: nanobind.nb_func
tan: nanobind.nb_func
tanh: nanobind.nb_func
wrap_to: nanobind.nb_func

class BarycentricMesh:
    def __init__(self, arg: collections.abc.Sequence[collections.abc.Set[float]]) -> None: ...
    def Eval(self, *args, **kwargs): ...
    def EvalBarycentricWeights(self, *args, **kwargs): ...
    def MeshValuesFrom(self, *args, **kwargs): ...
    def get_all_mesh_points(self, *args, **kwargs): ...
    def get_input_grid(self) -> list[set[float]]: ...
    def get_input_size(self) -> int: ...
    def get_mesh_point(self, *args, **kwargs): ...
    def get_num_interpolants(self) -> int: ...
    def get_num_mesh_points(self) -> int: ...

class BsplineBasis:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, order: int, knots: collections.abc.Sequence[float]) -> None: ...
    @overload
    def __init__(self, order: int, num_basis_functions: int, type: KnotVectorType = ..., initial_parameter_value: float = ..., final_parameter_value: float = ...) -> None: ...
    @overload
    def __init__(self, other: BsplineBasis) -> None: ...
    @overload
    def ComputeActiveBasisFunctionIndices(self, parameter_interval: collections.abc.Sequence[float]) -> list[int]: ...
    @overload
    def ComputeActiveBasisFunctionIndices(self, parameter_value: float) -> list[int]: ...
    def EvaluateBasisFunctionI(self, i: int, parameter_value: float) -> float: ...
    def EvaluateCurve(self, *args, **kwargs): ...
    def EvaluateLinearInControlPoints(self, *args, **kwargs): ...
    def FindContainingInterval(self, parameter_value: float) -> int: ...
    def degree(self) -> int: ...
    def final_parameter_value(self) -> float: ...
    def initial_parameter_value(self) -> float: ...
    def knots(self) -> list[float]: ...
    def num_basis_functions(self) -> int: ...
    def order(self) -> int: ...
    def __eq__(self, arg: BsplineBasis) -> bool: ...
    def __ne__(self, arg: BsplineBasis) -> bool: ...

class BsplineBasis_𝓣AutoDiffXd𝓤:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, order: int, knots: collections.abc.Sequence[pydrake.autodiffutils.AutoDiffXd]) -> None: ...
    @overload
    def __init__(self, order: int, num_basis_functions: int, type: KnotVectorType = ..., initial_parameter_value: pydrake.autodiffutils.AutoDiffXd = ..., final_parameter_value: pydrake.autodiffutils.AutoDiffXd = ...) -> None: ...
    @overload
    def __init__(self, other: BsplineBasis_TAutoDiffXdU) -> None: ...
    @overload
    def ComputeActiveBasisFunctionIndices(self, parameter_interval: collections.abc.Sequence[pydrake.autodiffutils.AutoDiffXd]) -> list[int]: ...
    @overload
    def ComputeActiveBasisFunctionIndices(self, parameter_value: pydrake.autodiffutils.AutoDiffXd) -> list[int]: ...
    def EvaluateBasisFunctionI(self, i: int, parameter_value: pydrake.autodiffutils.AutoDiffXd) -> pydrake.autodiffutils.AutoDiffXd: ...
    def EvaluateCurve(self, *args, **kwargs): ...
    def EvaluateLinearInControlPoints(self, *args, **kwargs): ...
    def FindContainingInterval(self, parameter_value: pydrake.autodiffutils.AutoDiffXd) -> int: ...
    def degree(self) -> int: ...
    def final_parameter_value(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def initial_parameter_value(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def knots(self) -> list[pydrake.autodiffutils.AutoDiffXd]: ...
    def num_basis_functions(self) -> int: ...
    def order(self) -> int: ...
    def __eq__(self, arg: BsplineBasis_TAutoDiffXdU) -> bool: ...
    def __ne__(self, arg: BsplineBasis_TAutoDiffXdU) -> bool: ...

class BsplineBasis_𝓣Expression𝓤:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, order: int, knots: collections.abc.Sequence[pydrake.symbolic.Expression]) -> None: ...
    @overload
    def __init__(self, order: int, num_basis_functions: int, type: KnotVectorType = ..., initial_parameter_value: pydrake.symbolic.Expression = ..., final_parameter_value: pydrake.symbolic.Expression = ...) -> None: ...
    @overload
    def __init__(self, other: BsplineBasis_TExpressionU) -> None: ...
    @overload
    def ComputeActiveBasisFunctionIndices(self, parameter_interval: collections.abc.Sequence[pydrake.symbolic.Expression]) -> list[int]: ...
    @overload
    def ComputeActiveBasisFunctionIndices(self, parameter_value: pydrake.symbolic.Expression) -> list[int]: ...
    def EvaluateBasisFunctionI(self, i: int, parameter_value: pydrake.symbolic.Expression) -> pydrake.symbolic.Expression: ...
    def EvaluateCurve(self, *args, **kwargs): ...
    def EvaluateLinearInControlPoints(self, *args, **kwargs): ...
    def FindContainingInterval(self, parameter_value: pydrake.symbolic.Expression) -> int: ...
    def degree(self) -> int: ...
    def final_parameter_value(self) -> pydrake.symbolic.Expression: ...
    def initial_parameter_value(self) -> pydrake.symbolic.Expression: ...
    def knots(self) -> list[pydrake.symbolic.Expression]: ...
    def num_basis_functions(self) -> int: ...
    def order(self) -> int: ...
    def __eq__(self, arg: BsplineBasis_TExpressionU) -> pydrake.symbolic.Formula: ...
    def __ne__(self, arg: BsplineBasis_TExpressionU) -> pydrake.symbolic.Formula: ...

class KnotVectorType(enum.IntEnum):
    __new__: ClassVar[Callable] = ...
    _generate_next_value_: ClassVar[Callable] = ...
    _hashable_values_: ClassVar[list] = ...
    _member_map_: ClassVar[dict] = ...
    _member_names_: ClassVar[list] = ...
    _member_type_: ClassVar[type[int]] = ...
    _unhashable_values_: ClassVar[list] = ...
    _unhashable_values_map_: ClassVar[dict] = ...
    _use_args_: ClassVar[bool] = ...
    _value2member_map_: ClassVar[dict] = ...
    kClampedUniform: ClassVar[KnotVectorType] = ...
    kUniform: ClassVar[KnotVectorType] = ...
    __nb_enum__: ClassVar[PyCapsule] = ...
    def __format__(self, *args, **kwargs) -> str: ...

class NumericalGradientMethod(enum.Enum):
    __new__: ClassVar[Callable] = ...
    _generate_next_value_: ClassVar[Callable] = ...
    _hashable_values_: ClassVar[list] = ...
    _member_map_: ClassVar[dict] = ...
    _member_names_: ClassVar[list] = ...
    _member_type_: ClassVar[type[object]] = ...
    _unhashable_values_: ClassVar[list] = ...
    _unhashable_values_map_: ClassVar[dict] = ...
    _use_args_: ClassVar[bool] = ...
    _value2member_map_: ClassVar[dict] = ...
    _value_repr_: ClassVar[None] = ...
    kBackward: ClassVar[NumericalGradientMethod] = ...
    kCentral: ClassVar[NumericalGradientMethod] = ...
    kForward: ClassVar[NumericalGradientMethod] = ...
    __nb_enum__: ClassVar[PyCapsule] = ...

class NumericalGradientOption:
    def __init__(self, method: NumericalGradientMethod, function_accuracy: float = ...) -> None: ...
    def NumericalGradientMethod(self) -> NumericalGradientMethod: ...
    def perturbation_size(self) -> float: ...

class RigidTransform:
    Identity: ClassVar[nanobind.nb_func] = ...
    MakeUnchecked: ClassVar[nanobind.nb_func] = ...
    cast𝓣AutoDiffXd𝓤: ClassVar[Callable] = ...
    cast𝓣Expression𝓤: ClassVar[Callable] = ...
    cast𝓣float𝓤: ClassVar[Callable] = ...
    multiply: ClassVar[Callable] = ...
    __matmul__: ClassVar[Callable] = ...
    cast: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: RigidTransform) -> None: ...
    @overload
    def __init__(self, R: RotationMatrix, p) -> None: ...
    @overload
    def __init__(self, rpy: RollPitchYaw, p) -> None: ...
    @overload
    def __init__(self, quaternion: pydrake.common.eigen_geometry.Quaternion, p) -> None: ...
    @overload
    def __init__(self, theta_lambda: pydrake.common.eigen_geometry.AngleAxis, p) -> None: ...
    @overload
    def __init__(self, R: RotationMatrix) -> None: ...
    @overload
    def __init__(self, p) -> None: ...
    @overload
    def __init__(self, pose: pydrake.common.eigen_geometry.Isometry3) -> None: ...
    @overload
    def __init__(self, pose) -> None: ...
    def GetAsIsometry3(self) -> pydrake.common.eigen_geometry.Isometry3: ...
    def GetAsMatrix34(self, *args, **kwargs): ...
    def GetAsMatrix4(self, *args, **kwargs): ...
    def GetMaximumAbsoluteDifference(self, other: RigidTransform) -> float: ...
    def GetMaximumAbsoluteTranslationDifference(self, other: RigidTransform) -> float: ...
    def InvertAndCompose(self, other: RigidTransform) -> RigidTransform: ...
    def IsExactlyEqualTo(self, other: RigidTransform) -> bool: ...
    def IsExactlyIdentity(self) -> bool: ...
    def IsNearlyEqualTo(self, other: RigidTransform, tolerance: float) -> bool: ...
    def IsNearlyIdentity(self, translation_tolerance: float) -> bool: ...
    def SetFromIsometry3(self, pose: pydrake.common.eigen_geometry.Isometry3) -> None: ...
    def SetIdentity(self) -> RigidTransform: ...
    def inverse(self) -> RigidTransform: ...
    def rotation(self) -> RotationMatrix: ...
    def set(self, R: RotationMatrix, p) -> None: ...
    @overload
    def set_rotation(self, R: RotationMatrix) -> None: ...
    @overload
    def set_rotation(self, rpy: RollPitchYaw) -> None: ...
    @overload
    def set_rotation(self, quaternion: pydrake.common.eigen_geometry.Quaternion) -> None: ...
    @overload
    def set_rotation(self, theta_lambda: pydrake.common.eigen_geometry.AngleAxis) -> None: ...
    def set_translation(self, p) -> None: ...
    def translation(self, *args, **kwargs): ...
    def __copy__(self) -> RigidTransform: ...
    def __deepcopy__(self, arg: dict) -> RigidTransform: ...

class RigidTransform_𝓣AutoDiffXd𝓤:
    Identity: ClassVar[nanobind.nb_func] = ...
    MakeUnchecked: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    cast𝓣AutoDiffXd𝓤: ClassVar[Callable] = ...
    multiply: ClassVar[Callable] = ...
    __matmul__: ClassVar[Callable] = ...
    cast: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: RigidTransform_TAutoDiffXdU) -> None: ...
    @overload
    def __init__(self, R: RotationMatrix_TAutoDiffXdU, p) -> None: ...
    @overload
    def __init__(self, rpy: RollPitchYaw_TAutoDiffXdU, p) -> None: ...
    @overload
    def __init__(self, quaternion: pydrake.common.eigen_geometry.Quaternion_TAutoDiffXdU, p) -> None: ...
    @overload
    def __init__(self, theta_lambda: pydrake.common.eigen_geometry.AngleAxis_TAutoDiffXdU, p) -> None: ...
    @overload
    def __init__(self, R: RotationMatrix_TAutoDiffXdU) -> None: ...
    @overload
    def __init__(self, p) -> None: ...
    @overload
    def __init__(self, pose: pydrake.common.eigen_geometry.Isometry3_TAutoDiffXdU) -> None: ...
    @overload
    def __init__(self, pose) -> None: ...
    def GetAsIsometry3(self) -> pydrake.common.eigen_geometry.Isometry3_TAutoDiffXdU: ...
    def GetAsMatrix34(self, *args, **kwargs): ...
    def GetAsMatrix4(self, *args, **kwargs): ...
    def GetMaximumAbsoluteDifference(self, other: RigidTransform_TAutoDiffXdU) -> pydrake.autodiffutils.AutoDiffXd: ...
    def GetMaximumAbsoluteTranslationDifference(self, other: RigidTransform_TAutoDiffXdU) -> pydrake.autodiffutils.AutoDiffXd: ...
    def InvertAndCompose(self, other: RigidTransform_TAutoDiffXdU) -> RigidTransform_TAutoDiffXdU: ...
    def IsExactlyEqualTo(self, other: RigidTransform_TAutoDiffXdU) -> bool: ...
    def IsExactlyIdentity(self) -> bool: ...
    def IsNearlyEqualTo(self, other: RigidTransform_TAutoDiffXdU, tolerance: float) -> bool: ...
    def IsNearlyIdentity(self, translation_tolerance: float) -> bool: ...
    def SetFromIsometry3(self, pose: pydrake.common.eigen_geometry.Isometry3_TAutoDiffXdU) -> None: ...
    def SetIdentity(self) -> RigidTransform_TAutoDiffXdU: ...
    def inverse(self) -> RigidTransform_TAutoDiffXdU: ...
    def rotation(self) -> RotationMatrix_TAutoDiffXdU: ...
    def set(self, R: RotationMatrix_TAutoDiffXdU, p) -> None: ...
    @overload
    def set_rotation(self, R: RotationMatrix_TAutoDiffXdU) -> None: ...
    @overload
    def set_rotation(self, rpy: RollPitchYaw_TAutoDiffXdU) -> None: ...
    @overload
    def set_rotation(self, quaternion: pydrake.common.eigen_geometry.Quaternion_TAutoDiffXdU) -> None: ...
    @overload
    def set_rotation(self, theta_lambda: pydrake.common.eigen_geometry.AngleAxis_TAutoDiffXdU) -> None: ...
    def set_translation(self, p) -> None: ...
    def translation(self, *args, **kwargs): ...
    def __copy__(self) -> RigidTransform_TAutoDiffXdU: ...
    def __deepcopy__(self, arg: dict) -> RigidTransform_TAutoDiffXdU: ...

class RigidTransform_𝓣Expression𝓤:
    Identity: ClassVar[nanobind.nb_func] = ...
    MakeUnchecked: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    cast𝓣Expression𝓤: ClassVar[Callable] = ...
    multiply: ClassVar[Callable] = ...
    __matmul__: ClassVar[Callable] = ...
    cast: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: RigidTransform_TExpressionU) -> None: ...
    @overload
    def __init__(self, R: RotationMatrix_TExpressionU, p) -> None: ...
    @overload
    def __init__(self, rpy: RollPitchYaw_TExpressionU, p) -> None: ...
    @overload
    def __init__(self, quaternion: pydrake.common.eigen_geometry.Quaternion_TExpressionU, p) -> None: ...
    @overload
    def __init__(self, theta_lambda: pydrake.common.eigen_geometry.AngleAxis_TExpressionU, p) -> None: ...
    @overload
    def __init__(self, R: RotationMatrix_TExpressionU) -> None: ...
    @overload
    def __init__(self, p) -> None: ...
    @overload
    def __init__(self, pose: pydrake.common.eigen_geometry.Isometry3_TExpressionU) -> None: ...
    @overload
    def __init__(self, pose) -> None: ...
    def GetAsIsometry3(self) -> pydrake.common.eigen_geometry.Isometry3_TExpressionU: ...
    def GetAsMatrix34(self, *args, **kwargs): ...
    def GetAsMatrix4(self, *args, **kwargs): ...
    def GetMaximumAbsoluteDifference(self, other: RigidTransform_TExpressionU) -> pydrake.symbolic.Expression: ...
    def GetMaximumAbsoluteTranslationDifference(self, other: RigidTransform_TExpressionU) -> pydrake.symbolic.Expression: ...
    def InvertAndCompose(self, other: RigidTransform_TExpressionU) -> RigidTransform_TExpressionU: ...
    def IsExactlyEqualTo(self, other: RigidTransform_TExpressionU) -> pydrake.symbolic.Formula: ...
    def IsExactlyIdentity(self) -> pydrake.symbolic.Formula: ...
    def IsNearlyEqualTo(self, other: RigidTransform_TExpressionU, tolerance: float) -> pydrake.symbolic.Formula: ...
    def IsNearlyIdentity(self, translation_tolerance: float) -> pydrake.symbolic.Formula: ...
    def SetFromIsometry3(self, pose: pydrake.common.eigen_geometry.Isometry3_TExpressionU) -> None: ...
    def SetIdentity(self) -> RigidTransform_TExpressionU: ...
    def inverse(self) -> RigidTransform_TExpressionU: ...
    def rotation(self) -> RotationMatrix_TExpressionU: ...
    def set(self, R: RotationMatrix_TExpressionU, p) -> None: ...
    @overload
    def set_rotation(self, R: RotationMatrix_TExpressionU) -> None: ...
    @overload
    def set_rotation(self, rpy: RollPitchYaw_TExpressionU) -> None: ...
    @overload
    def set_rotation(self, quaternion: pydrake.common.eigen_geometry.Quaternion_TExpressionU) -> None: ...
    @overload
    def set_rotation(self, theta_lambda: pydrake.common.eigen_geometry.AngleAxis_TExpressionU) -> None: ...
    def set_translation(self, p) -> None: ...
    def translation(self, *args, **kwargs): ...
    def __copy__(self) -> RigidTransform_TExpressionU: ...
    def __deepcopy__(self, arg: dict) -> RigidTransform_TExpressionU: ...

class RollPitchYaw:
    @overload
    def __init__(self, other: RollPitchYaw) -> None: ...
    @overload
    def __init__(self, rpy) -> None: ...
    @overload
    def __init__(self, roll: float, pitch: float, yaw: float) -> None: ...
    @overload
    def __init__(self, R: RotationMatrix) -> None: ...
    @overload
    def __init__(self, quaternion: pydrake.common.eigen_geometry.Quaternion) -> None: ...
    @overload
    def __init__(self, matrix) -> None: ...
    def CalcAngularVelocityInChildFromRpyDt(self, *args, **kwargs): ...
    def CalcAngularVelocityInParentFromRpyDt(self, *args, **kwargs): ...
    def CalcRotationMatrixDt(self, *args, **kwargs): ...
    def CalcRpyDDtFromAngularAccelInChild(self, *args, **kwargs): ...
    def CalcRpyDDtFromRpyDtAndAngularAccelInParent(self, *args, **kwargs): ...
    def CalcRpyDtFromAngularVelocityInChild(self, *args, **kwargs): ...
    def CalcRpyDtFromAngularVelocityInParent(self, *args, **kwargs): ...
    def IsNearlyEqualTo(self, other: RollPitchYaw, tolerance: float) -> bool: ...
    def ToQuaternion(self) -> pydrake.common.eigen_geometry.Quaternion: ...
    def ToRotationMatrix(self) -> RotationMatrix: ...
    def pitch_angle(self) -> float: ...
    def roll_angle(self) -> float: ...
    def vector(self, *args, **kwargs): ...
    def yaw_angle(self) -> float: ...
    def __copy__(self) -> RollPitchYaw: ...
    def __deepcopy__(self, arg: dict) -> RollPitchYaw: ...

class RollPitchYaw_𝓣AutoDiffXd𝓤:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, other: RollPitchYaw_TAutoDiffXdU) -> None: ...
    @overload
    def __init__(self, rpy) -> None: ...
    @overload
    def __init__(self, roll: pydrake.autodiffutils.AutoDiffXd, pitch: pydrake.autodiffutils.AutoDiffXd, yaw: pydrake.autodiffutils.AutoDiffXd) -> None: ...
    @overload
    def __init__(self, R: RotationMatrix_TAutoDiffXdU) -> None: ...
    @overload
    def __init__(self, quaternion: pydrake.common.eigen_geometry.Quaternion_TAutoDiffXdU) -> None: ...
    @overload
    def __init__(self, matrix) -> None: ...
    def CalcAngularVelocityInChildFromRpyDt(self, *args, **kwargs): ...
    def CalcAngularVelocityInParentFromRpyDt(self, *args, **kwargs): ...
    def CalcRotationMatrixDt(self, *args, **kwargs): ...
    def CalcRpyDDtFromAngularAccelInChild(self, *args, **kwargs): ...
    def CalcRpyDDtFromRpyDtAndAngularAccelInParent(self, *args, **kwargs): ...
    def CalcRpyDtFromAngularVelocityInChild(self, *args, **kwargs): ...
    def CalcRpyDtFromAngularVelocityInParent(self, *args, **kwargs): ...
    def IsNearlyEqualTo(self, other: RollPitchYaw_TAutoDiffXdU, tolerance: float) -> bool: ...
    def ToQuaternion(self) -> pydrake.common.eigen_geometry.Quaternion_TAutoDiffXdU: ...
    def ToRotationMatrix(self) -> RotationMatrix_TAutoDiffXdU: ...
    def pitch_angle(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def roll_angle(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def vector(self, *args, **kwargs): ...
    def yaw_angle(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def __copy__(self) -> RollPitchYaw_TAutoDiffXdU: ...
    def __deepcopy__(self, arg: dict) -> RollPitchYaw_TAutoDiffXdU: ...

class RollPitchYaw_𝓣Expression𝓤:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, other: RollPitchYaw_TExpressionU) -> None: ...
    @overload
    def __init__(self, rpy) -> None: ...
    @overload
    def __init__(self, roll: pydrake.symbolic.Expression, pitch: pydrake.symbolic.Expression, yaw: pydrake.symbolic.Expression) -> None: ...
    @overload
    def __init__(self, R: RotationMatrix_TExpressionU) -> None: ...
    @overload
    def __init__(self, quaternion: pydrake.common.eigen_geometry.Quaternion_TExpressionU) -> None: ...
    @overload
    def __init__(self, matrix) -> None: ...
    def CalcAngularVelocityInChildFromRpyDt(self, *args, **kwargs): ...
    def CalcAngularVelocityInParentFromRpyDt(self, *args, **kwargs): ...
    def CalcRotationMatrixDt(self, *args, **kwargs): ...
    def CalcRpyDDtFromAngularAccelInChild(self, *args, **kwargs): ...
    def CalcRpyDDtFromRpyDtAndAngularAccelInParent(self, *args, **kwargs): ...
    def CalcRpyDtFromAngularVelocityInChild(self, *args, **kwargs): ...
    def CalcRpyDtFromAngularVelocityInParent(self, *args, **kwargs): ...
    def IsNearlyEqualTo(self, other: RollPitchYaw_TExpressionU, tolerance: float) -> pydrake.symbolic.Formula: ...
    def ToQuaternion(self) -> pydrake.common.eigen_geometry.Quaternion_TExpressionU: ...
    def ToRotationMatrix(self) -> RotationMatrix_TExpressionU: ...
    def pitch_angle(self) -> pydrake.symbolic.Expression: ...
    def roll_angle(self) -> pydrake.symbolic.Expression: ...
    def vector(self, *args, **kwargs): ...
    def yaw_angle(self) -> pydrake.symbolic.Expression: ...
    def __copy__(self) -> RollPitchYaw_TExpressionU: ...
    def __deepcopy__(self, arg: dict) -> RollPitchYaw_TExpressionU: ...

class RotationMatrix:
    Identity: ClassVar[nanobind.nb_func] = ...
    MakeFromOneVector: ClassVar[nanobind.nb_func] = ...
    MakeUnchecked: ClassVar[nanobind.nb_func] = ...
    MakeXRotation: ClassVar[nanobind.nb_func] = ...
    MakeYRotation: ClassVar[nanobind.nb_func] = ...
    MakeZRotation: ClassVar[nanobind.nb_func] = ...
    ProjectToRotationMatrix: ClassVar[nanobind.nb_func] = ...
    cast𝓣AutoDiffXd𝓤: ClassVar[Callable] = ...
    cast𝓣Expression𝓤: ClassVar[Callable] = ...
    cast𝓣float𝓤: ClassVar[Callable] = ...
    multiply: ClassVar[Callable] = ...
    __matmul__: ClassVar[Callable] = ...
    cast: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def InvertAndCompose(self, other: RotationMatrix) -> RotationMatrix: ...
    def IsExactlyEqualTo(self, other: RotationMatrix) -> bool: ...
    def IsExactlyIdentity(self) -> bool: ...
    def IsNearlyEqualTo(self, other: RotationMatrix, tolerance: float) -> bool: ...
    def IsNearlyIdentity(self, tolerance: float = ...) -> bool: ...
    def IsValid(self) -> bool: ...
    def ToAngleAxis(self) -> pydrake.common.eigen_geometry.AngleAxis: ...
    def ToQuaternion(self) -> pydrake.common.eigen_geometry.Quaternion: ...
    def ToRollPitchYaw(self) -> RollPitchYaw: ...
    def col(self, *args, **kwargs): ...
    def inverse(self) -> RotationMatrix: ...
    def matrix(self, *args, **kwargs): ...
    def row(self, *args, **kwargs): ...
    def set(self, R) -> None: ...
    def transpose(self) -> RotationMatrix: ...
    def __copy__(self) -> RotationMatrix: ...
    def __deepcopy__(self, arg: dict) -> RotationMatrix: ...

class RotationMatrix_𝓣AutoDiffXd𝓤:
    Identity: ClassVar[nanobind.nb_func] = ...
    MakeFromOneVector: ClassVar[nanobind.nb_func] = ...
    MakeUnchecked: ClassVar[nanobind.nb_func] = ...
    MakeXRotation: ClassVar[nanobind.nb_func] = ...
    MakeYRotation: ClassVar[nanobind.nb_func] = ...
    MakeZRotation: ClassVar[nanobind.nb_func] = ...
    ProjectToRotationMatrix: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    cast𝓣AutoDiffXd𝓤: ClassVar[Callable] = ...
    multiply: ClassVar[Callable] = ...
    __matmul__: ClassVar[Callable] = ...
    cast: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def InvertAndCompose(self, other: RotationMatrix_TAutoDiffXdU) -> RotationMatrix_TAutoDiffXdU: ...
    def IsExactlyEqualTo(self, other: RotationMatrix_TAutoDiffXdU) -> bool: ...
    def IsExactlyIdentity(self) -> bool: ...
    def IsNearlyEqualTo(self, other: RotationMatrix_TAutoDiffXdU, tolerance: float) -> bool: ...
    def IsNearlyIdentity(self, tolerance: float = ...) -> bool: ...
    def IsValid(self) -> bool: ...
    def ToAngleAxis(self) -> pydrake.common.eigen_geometry.AngleAxis_TAutoDiffXdU: ...
    def ToQuaternion(self) -> pydrake.common.eigen_geometry.Quaternion_TAutoDiffXdU: ...
    def ToRollPitchYaw(self) -> RollPitchYaw_TAutoDiffXdU: ...
    def col(self, *args, **kwargs): ...
    def inverse(self) -> RotationMatrix_TAutoDiffXdU: ...
    def matrix(self, *args, **kwargs): ...
    def row(self, *args, **kwargs): ...
    def set(self, R) -> None: ...
    def transpose(self) -> RotationMatrix_TAutoDiffXdU: ...
    def __copy__(self) -> RotationMatrix_TAutoDiffXdU: ...
    def __deepcopy__(self, arg: dict) -> RotationMatrix_TAutoDiffXdU: ...

class RotationMatrix_𝓣Expression𝓤:
    Identity: ClassVar[nanobind.nb_func] = ...
    MakeFromOneVector: ClassVar[nanobind.nb_func] = ...
    MakeUnchecked: ClassVar[nanobind.nb_func] = ...
    MakeXRotation: ClassVar[nanobind.nb_func] = ...
    MakeYRotation: ClassVar[nanobind.nb_func] = ...
    MakeZRotation: ClassVar[nanobind.nb_func] = ...
    ProjectToRotationMatrix: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    cast𝓣Expression𝓤: ClassVar[Callable] = ...
    multiply: ClassVar[Callable] = ...
    __matmul__: ClassVar[Callable] = ...
    cast: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def InvertAndCompose(self, other: RotationMatrix_TExpressionU) -> RotationMatrix_TExpressionU: ...
    def IsExactlyEqualTo(self, other: RotationMatrix_TExpressionU) -> pydrake.symbolic.Formula: ...
    def IsExactlyIdentity(self) -> pydrake.symbolic.Formula: ...
    def IsNearlyEqualTo(self, other: RotationMatrix_TExpressionU, tolerance: float) -> pydrake.symbolic.Formula: ...
    def IsNearlyIdentity(self, tolerance: float = ...) -> pydrake.symbolic.Formula: ...
    def IsValid(self) -> pydrake.symbolic.Formula: ...
    def ToAngleAxis(self) -> pydrake.common.eigen_geometry.AngleAxis_TExpressionU: ...
    def ToQuaternion(self) -> pydrake.common.eigen_geometry.Quaternion_TExpressionU: ...
    def ToRollPitchYaw(self) -> RollPitchYaw_TExpressionU: ...
    def col(self, *args, **kwargs): ...
    def inverse(self) -> RotationMatrix_TExpressionU: ...
    def matrix(self, *args, **kwargs): ...
    def row(self, *args, **kwargs): ...
    def set(self, R) -> None: ...
    def transpose(self) -> RotationMatrix_TExpressionU: ...
    def __copy__(self) -> RotationMatrix_TExpressionU: ...
    def __deepcopy__(self, arg: dict) -> RotationMatrix_TExpressionU: ...

class _TemporaryName_N5drake4math12BsplineBasisINS_2ad8AutoDiffEEE:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, order: int, knots: collections.abc.Sequence[pydrake.autodiffutils.AutoDiffXd]) -> None: ...
    @overload
    def __init__(self, order: int, num_basis_functions: int, type: KnotVectorType = ..., initial_parameter_value: pydrake.autodiffutils.AutoDiffXd = ..., final_parameter_value: pydrake.autodiffutils.AutoDiffXd = ...) -> None: ...
    @overload
    def __init__(self, other: BsplineBasis_TAutoDiffXdU) -> None: ...
    @overload
    def ComputeActiveBasisFunctionIndices(self, parameter_interval: collections.abc.Sequence[pydrake.autodiffutils.AutoDiffXd]) -> list[int]: ...
    @overload
    def ComputeActiveBasisFunctionIndices(self, parameter_value: pydrake.autodiffutils.AutoDiffXd) -> list[int]: ...
    def EvaluateBasisFunctionI(self, i: int, parameter_value: pydrake.autodiffutils.AutoDiffXd) -> pydrake.autodiffutils.AutoDiffXd: ...
    def EvaluateCurve(self, *args, **kwargs): ...
    def EvaluateLinearInControlPoints(self, *args, **kwargs): ...
    def FindContainingInterval(self, parameter_value: pydrake.autodiffutils.AutoDiffXd) -> int: ...
    def degree(self) -> int: ...
    def final_parameter_value(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def initial_parameter_value(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def knots(self) -> list[pydrake.autodiffutils.AutoDiffXd]: ...
    def num_basis_functions(self) -> int: ...
    def order(self) -> int: ...
    def __eq__(self, arg: BsplineBasis_TAutoDiffXdU) -> bool: ...
    def __ne__(self, arg: BsplineBasis_TAutoDiffXdU) -> bool: ...

class _TemporaryName_N5drake4math12BsplineBasisINS_8symbolic10ExpressionEEE:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, order: int, knots: collections.abc.Sequence[pydrake.symbolic.Expression]) -> None: ...
    @overload
    def __init__(self, order: int, num_basis_functions: int, type: KnotVectorType = ..., initial_parameter_value: pydrake.symbolic.Expression = ..., final_parameter_value: pydrake.symbolic.Expression = ...) -> None: ...
    @overload
    def __init__(self, other: BsplineBasis_TExpressionU) -> None: ...
    @overload
    def ComputeActiveBasisFunctionIndices(self, parameter_interval: collections.abc.Sequence[pydrake.symbolic.Expression]) -> list[int]: ...
    @overload
    def ComputeActiveBasisFunctionIndices(self, parameter_value: pydrake.symbolic.Expression) -> list[int]: ...
    def EvaluateBasisFunctionI(self, i: int, parameter_value: pydrake.symbolic.Expression) -> pydrake.symbolic.Expression: ...
    def EvaluateCurve(self, *args, **kwargs): ...
    def EvaluateLinearInControlPoints(self, *args, **kwargs): ...
    def FindContainingInterval(self, parameter_value: pydrake.symbolic.Expression) -> int: ...
    def degree(self) -> int: ...
    def final_parameter_value(self) -> pydrake.symbolic.Expression: ...
    def initial_parameter_value(self) -> pydrake.symbolic.Expression: ...
    def knots(self) -> list[pydrake.symbolic.Expression]: ...
    def num_basis_functions(self) -> int: ...
    def order(self) -> int: ...
    def __eq__(self, arg: BsplineBasis_TExpressionU) -> pydrake.symbolic.Formula: ...
    def __ne__(self, arg: BsplineBasis_TExpressionU) -> pydrake.symbolic.Formula: ...

class _TemporaryName_N5drake4math12RollPitchYawINS_2ad8AutoDiffEEE:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, other: RollPitchYaw_TAutoDiffXdU) -> None: ...
    @overload
    def __init__(self, rpy) -> None: ...
    @overload
    def __init__(self, roll: pydrake.autodiffutils.AutoDiffXd, pitch: pydrake.autodiffutils.AutoDiffXd, yaw: pydrake.autodiffutils.AutoDiffXd) -> None: ...
    @overload
    def __init__(self, R: RotationMatrix_TAutoDiffXdU) -> None: ...
    @overload
    def __init__(self, quaternion: pydrake.common.eigen_geometry.Quaternion_TAutoDiffXdU) -> None: ...
    @overload
    def __init__(self, matrix) -> None: ...
    def CalcAngularVelocityInChildFromRpyDt(self, *args, **kwargs): ...
    def CalcAngularVelocityInParentFromRpyDt(self, *args, **kwargs): ...
    def CalcRotationMatrixDt(self, *args, **kwargs): ...
    def CalcRpyDDtFromAngularAccelInChild(self, *args, **kwargs): ...
    def CalcRpyDDtFromRpyDtAndAngularAccelInParent(self, *args, **kwargs): ...
    def CalcRpyDtFromAngularVelocityInChild(self, *args, **kwargs): ...
    def CalcRpyDtFromAngularVelocityInParent(self, *args, **kwargs): ...
    def IsNearlyEqualTo(self, other: RollPitchYaw_TAutoDiffXdU, tolerance: float) -> bool: ...
    def ToQuaternion(self) -> pydrake.common.eigen_geometry.Quaternion_TAutoDiffXdU: ...
    def ToRotationMatrix(self) -> RotationMatrix_TAutoDiffXdU: ...
    def pitch_angle(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def roll_angle(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def vector(self, *args, **kwargs): ...
    def yaw_angle(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def __copy__(self) -> RollPitchYaw_TAutoDiffXdU: ...
    def __deepcopy__(self, arg: dict) -> RollPitchYaw_TAutoDiffXdU: ...

class _TemporaryName_N5drake4math12RollPitchYawINS_8symbolic10ExpressionEEE:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, other: RollPitchYaw_TExpressionU) -> None: ...
    @overload
    def __init__(self, rpy) -> None: ...
    @overload
    def __init__(self, roll: pydrake.symbolic.Expression, pitch: pydrake.symbolic.Expression, yaw: pydrake.symbolic.Expression) -> None: ...
    @overload
    def __init__(self, R: RotationMatrix_TExpressionU) -> None: ...
    @overload
    def __init__(self, quaternion: pydrake.common.eigen_geometry.Quaternion_TExpressionU) -> None: ...
    @overload
    def __init__(self, matrix) -> None: ...
    def CalcAngularVelocityInChildFromRpyDt(self, *args, **kwargs): ...
    def CalcAngularVelocityInParentFromRpyDt(self, *args, **kwargs): ...
    def CalcRotationMatrixDt(self, *args, **kwargs): ...
    def CalcRpyDDtFromAngularAccelInChild(self, *args, **kwargs): ...
    def CalcRpyDDtFromRpyDtAndAngularAccelInParent(self, *args, **kwargs): ...
    def CalcRpyDtFromAngularVelocityInChild(self, *args, **kwargs): ...
    def CalcRpyDtFromAngularVelocityInParent(self, *args, **kwargs): ...
    def IsNearlyEqualTo(self, other: RollPitchYaw_TExpressionU, tolerance: float) -> pydrake.symbolic.Formula: ...
    def ToQuaternion(self) -> pydrake.common.eigen_geometry.Quaternion_TExpressionU: ...
    def ToRotationMatrix(self) -> RotationMatrix_TExpressionU: ...
    def pitch_angle(self) -> pydrake.symbolic.Expression: ...
    def roll_angle(self) -> pydrake.symbolic.Expression: ...
    def vector(self, *args, **kwargs): ...
    def yaw_angle(self) -> pydrake.symbolic.Expression: ...
    def __copy__(self) -> RollPitchYaw_TExpressionU: ...
    def __deepcopy__(self, arg: dict) -> RollPitchYaw_TExpressionU: ...

class _TemporaryName_N5drake4math14RigidTransformINS_2ad8AutoDiffEEE:
    Identity: ClassVar[nanobind.nb_func] = ...
    MakeUnchecked: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    cast𝓣AutoDiffXd𝓤: ClassVar[Callable] = ...
    multiply: ClassVar[Callable] = ...
    __matmul__: ClassVar[Callable] = ...
    cast: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: RigidTransform_TAutoDiffXdU) -> None: ...
    @overload
    def __init__(self, R: RotationMatrix_TAutoDiffXdU, p) -> None: ...
    @overload
    def __init__(self, rpy: RollPitchYaw_TAutoDiffXdU, p) -> None: ...
    @overload
    def __init__(self, quaternion: pydrake.common.eigen_geometry.Quaternion_TAutoDiffXdU, p) -> None: ...
    @overload
    def __init__(self, theta_lambda: pydrake.common.eigen_geometry.AngleAxis_TAutoDiffXdU, p) -> None: ...
    @overload
    def __init__(self, R: RotationMatrix_TAutoDiffXdU) -> None: ...
    @overload
    def __init__(self, p) -> None: ...
    @overload
    def __init__(self, pose: pydrake.common.eigen_geometry.Isometry3_TAutoDiffXdU) -> None: ...
    @overload
    def __init__(self, pose) -> None: ...
    def GetAsIsometry3(self) -> pydrake.common.eigen_geometry.Isometry3_TAutoDiffXdU: ...
    def GetAsMatrix34(self, *args, **kwargs): ...
    def GetAsMatrix4(self, *args, **kwargs): ...
    def GetMaximumAbsoluteDifference(self, other: RigidTransform_TAutoDiffXdU) -> pydrake.autodiffutils.AutoDiffXd: ...
    def GetMaximumAbsoluteTranslationDifference(self, other: RigidTransform_TAutoDiffXdU) -> pydrake.autodiffutils.AutoDiffXd: ...
    def InvertAndCompose(self, other: RigidTransform_TAutoDiffXdU) -> RigidTransform_TAutoDiffXdU: ...
    def IsExactlyEqualTo(self, other: RigidTransform_TAutoDiffXdU) -> bool: ...
    def IsExactlyIdentity(self) -> bool: ...
    def IsNearlyEqualTo(self, other: RigidTransform_TAutoDiffXdU, tolerance: float) -> bool: ...
    def IsNearlyIdentity(self, translation_tolerance: float) -> bool: ...
    def SetFromIsometry3(self, pose: pydrake.common.eigen_geometry.Isometry3_TAutoDiffXdU) -> None: ...
    def SetIdentity(self) -> RigidTransform_TAutoDiffXdU: ...
    def inverse(self) -> RigidTransform_TAutoDiffXdU: ...
    def rotation(self) -> RotationMatrix_TAutoDiffXdU: ...
    def set(self, R: RotationMatrix_TAutoDiffXdU, p) -> None: ...
    @overload
    def set_rotation(self, R: RotationMatrix_TAutoDiffXdU) -> None: ...
    @overload
    def set_rotation(self, rpy: RollPitchYaw_TAutoDiffXdU) -> None: ...
    @overload
    def set_rotation(self, quaternion: pydrake.common.eigen_geometry.Quaternion_TAutoDiffXdU) -> None: ...
    @overload
    def set_rotation(self, theta_lambda: pydrake.common.eigen_geometry.AngleAxis_TAutoDiffXdU) -> None: ...
    def set_translation(self, p) -> None: ...
    def translation(self, *args, **kwargs): ...
    def __copy__(self) -> RigidTransform_TAutoDiffXdU: ...
    def __deepcopy__(self, arg: dict) -> RigidTransform_TAutoDiffXdU: ...

class _TemporaryName_N5drake4math14RigidTransformINS_8symbolic10ExpressionEEE:
    Identity: ClassVar[nanobind.nb_func] = ...
    MakeUnchecked: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    cast𝓣Expression𝓤: ClassVar[Callable] = ...
    multiply: ClassVar[Callable] = ...
    __matmul__: ClassVar[Callable] = ...
    cast: Incomplete
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: RigidTransform_TExpressionU) -> None: ...
    @overload
    def __init__(self, R: RotationMatrix_TExpressionU, p) -> None: ...
    @overload
    def __init__(self, rpy: RollPitchYaw_TExpressionU, p) -> None: ...
    @overload
    def __init__(self, quaternion: pydrake.common.eigen_geometry.Quaternion_TExpressionU, p) -> None: ...
    @overload
    def __init__(self, theta_lambda: pydrake.common.eigen_geometry.AngleAxis_TExpressionU, p) -> None: ...
    @overload
    def __init__(self, R: RotationMatrix_TExpressionU) -> None: ...
    @overload
    def __init__(self, p) -> None: ...
    @overload
    def __init__(self, pose: pydrake.common.eigen_geometry.Isometry3_TExpressionU) -> None: ...
    @overload
    def __init__(self, pose) -> None: ...
    def GetAsIsometry3(self) -> pydrake.common.eigen_geometry.Isometry3_TExpressionU: ...
    def GetAsMatrix34(self, *args, **kwargs): ...
    def GetAsMatrix4(self, *args, **kwargs): ...
    def GetMaximumAbsoluteDifference(self, other: RigidTransform_TExpressionU) -> pydrake.symbolic.Expression: ...
    def GetMaximumAbsoluteTranslationDifference(self, other: RigidTransform_TExpressionU) -> pydrake.symbolic.Expression: ...
    def InvertAndCompose(self, other: RigidTransform_TExpressionU) -> RigidTransform_TExpressionU: ...
    def IsExactlyEqualTo(self, other: RigidTransform_TExpressionU) -> pydrake.symbolic.Formula: ...
    def IsExactlyIdentity(self) -> pydrake.symbolic.Formula: ...
    def IsNearlyEqualTo(self, other: RigidTransform_TExpressionU, tolerance: float) -> pydrake.symbolic.Formula: ...
    def IsNearlyIdentity(self, translation_tolerance: float) -> pydrake.symbolic.Formula: ...
    def SetFromIsometry3(self, pose: pydrake.common.eigen_geometry.Isometry3_TExpressionU) -> None: ...
    def SetIdentity(self) -> RigidTransform_TExpressionU: ...
    def inverse(self) -> RigidTransform_TExpressionU: ...
    def rotation(self) -> RotationMatrix_TExpressionU: ...
    def set(self, R: RotationMatrix_TExpressionU, p) -> None: ...
    @overload
    def set_rotation(self, R: RotationMatrix_TExpressionU) -> None: ...
    @overload
    def set_rotation(self, rpy: RollPitchYaw_TExpressionU) -> None: ...
    @overload
    def set_rotation(self, quaternion: pydrake.common.eigen_geometry.Quaternion_TExpressionU) -> None: ...
    @overload
    def set_rotation(self, theta_lambda: pydrake.common.eigen_geometry.AngleAxis_TExpressionU) -> None: ...
    def set_translation(self, p) -> None: ...
    def translation(self, *args, **kwargs): ...
    def __copy__(self) -> RigidTransform_TExpressionU: ...
    def __deepcopy__(self, arg: dict) -> RigidTransform_TExpressionU: ...

class _TemporaryName_N5drake4math14RotationMatrixINS_2ad8AutoDiffEEE:
    Identity: ClassVar[nanobind.nb_func] = ...
    MakeFromOneVector: ClassVar[nanobind.nb_func] = ...
    MakeUnchecked: ClassVar[nanobind.nb_func] = ...
    MakeXRotation: ClassVar[nanobind.nb_func] = ...
    MakeYRotation: ClassVar[nanobind.nb_func] = ...
    MakeZRotation: ClassVar[nanobind.nb_func] = ...
    ProjectToRotationMatrix: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    cast𝓣AutoDiffXd𝓤: ClassVar[Callable] = ...
    multiply: ClassVar[Callable] = ...
    __matmul__: ClassVar[Callable] = ...
    cast: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def InvertAndCompose(self, other: RotationMatrix_TAutoDiffXdU) -> RotationMatrix_TAutoDiffXdU: ...
    def IsExactlyEqualTo(self, other: RotationMatrix_TAutoDiffXdU) -> bool: ...
    def IsExactlyIdentity(self) -> bool: ...
    def IsNearlyEqualTo(self, other: RotationMatrix_TAutoDiffXdU, tolerance: float) -> bool: ...
    def IsNearlyIdentity(self, tolerance: float = ...) -> bool: ...
    def IsValid(self) -> bool: ...
    def ToAngleAxis(self) -> pydrake.common.eigen_geometry.AngleAxis_TAutoDiffXdU: ...
    def ToQuaternion(self) -> pydrake.common.eigen_geometry.Quaternion_TAutoDiffXdU: ...
    def ToRollPitchYaw(self) -> RollPitchYaw_TAutoDiffXdU: ...
    def col(self, *args, **kwargs): ...
    def inverse(self) -> RotationMatrix_TAutoDiffXdU: ...
    def matrix(self, *args, **kwargs): ...
    def row(self, *args, **kwargs): ...
    def set(self, R) -> None: ...
    def transpose(self) -> RotationMatrix_TAutoDiffXdU: ...
    def __copy__(self) -> RotationMatrix_TAutoDiffXdU: ...
    def __deepcopy__(self, arg: dict) -> RotationMatrix_TAutoDiffXdU: ...

class _TemporaryName_N5drake4math14RotationMatrixINS_8symbolic10ExpressionEEE:
    Identity: ClassVar[nanobind.nb_func] = ...
    MakeFromOneVector: ClassVar[nanobind.nb_func] = ...
    MakeUnchecked: ClassVar[nanobind.nb_func] = ...
    MakeXRotation: ClassVar[nanobind.nb_func] = ...
    MakeYRotation: ClassVar[nanobind.nb_func] = ...
    MakeZRotation: ClassVar[nanobind.nb_func] = ...
    ProjectToRotationMatrix: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    cast𝓣Expression𝓤: ClassVar[Callable] = ...
    multiply: ClassVar[Callable] = ...
    __matmul__: ClassVar[Callable] = ...
    cast: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def InvertAndCompose(self, other: RotationMatrix_TExpressionU) -> RotationMatrix_TExpressionU: ...
    def IsExactlyEqualTo(self, other: RotationMatrix_TExpressionU) -> pydrake.symbolic.Formula: ...
    def IsExactlyIdentity(self) -> pydrake.symbolic.Formula: ...
    def IsNearlyEqualTo(self, other: RotationMatrix_TExpressionU, tolerance: float) -> pydrake.symbolic.Formula: ...
    def IsNearlyIdentity(self, tolerance: float = ...) -> pydrake.symbolic.Formula: ...
    def IsValid(self) -> pydrake.symbolic.Formula: ...
    def ToAngleAxis(self) -> pydrake.common.eigen_geometry.AngleAxis_TExpressionU: ...
    def ToQuaternion(self) -> pydrake.common.eigen_geometry.Quaternion_TExpressionU: ...
    def ToRollPitchYaw(self) -> RollPitchYaw_TExpressionU: ...
    def col(self, *args, **kwargs): ...
    def inverse(self) -> RotationMatrix_TExpressionU: ...
    def matrix(self, *args, **kwargs): ...
    def row(self, *args, **kwargs): ...
    def set(self, R) -> None: ...
    def transpose(self) -> RotationMatrix_TExpressionU: ...
    def __copy__(self) -> RotationMatrix_TExpressionU: ...
    def __deepcopy__(self, arg: dict) -> RotationMatrix_TExpressionU: ...



import pydrake.multibody.plant
import pydrake.multibody.tree
import pydrake.symbolic
from pydrake.common.cpp_template import RationalForwardKinematicsPose_ as RationalForwardKinematicsPose_
from typing import ClassVar

class RationalForwardKinematics:
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant) -> None: ...
    def CalcBodyPoseAsMultilinearPolynomial(self, q_star, body_index: pydrake.multibody.tree.BodyIndex, expressed_body_index: pydrake.multibody.tree.BodyIndex) -> RationalForwardKinematicsPose: ...
    def ComputeQValue(self, *args, **kwargs): ...
    def ComputeSValue(self, *args, **kwargs): ...
    def ConvertMultilinearPolynomialToRationalFunction(self, e: pydrake.symbolic.Polynomial) -> pydrake.symbolic.RationalFunction: ...
    def plant(self) -> pydrake.multibody.plant.MultibodyPlant: ...
    def s(self, *args, **kwargs): ...

class RationalForwardKinematicsPose:
    def __init__(self, *args, **kwargs) -> None: ...
    def position(self, *args, **kwargs): ...
    def rotation(self, *args, **kwargs): ...
    def __copy__(self) -> RationalForwardKinematicsPose: ...
    def __deepcopy__(self, arg: dict) -> RationalForwardKinematicsPose: ...

class RationalForwardKinematicsPose_𝓣RationalFunction𝓤:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def position(self, *args, **kwargs): ...
    def rotation(self, *args, **kwargs): ...
    def __copy__(self) -> RationalForwardKinematicsPose_TRationalFunctionU: ...
    def __deepcopy__(self, arg: dict) -> RationalForwardKinematicsPose_TRationalFunctionU: ...

class _TemporaryName_N5drake9multibody25RationalForwardKinematics4PoseINS_8symbolic16RationalFunctionEEE:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def position(self, *args, **kwargs): ...
    def rotation(self, *args, **kwargs): ...
    def __copy__(self) -> RationalForwardKinematicsPose_TRationalFunctionU: ...
    def __deepcopy__(self, arg: dict) -> RationalForwardKinematicsPose_TRationalFunctionU: ...



import nanobind
import pydrake.geometry
import pydrake.systems.framework
from typing import ClassVar, overload

StabilizingLQRController: nanobind.nb_func

class AcrobotGeometry(pydrake.systems.framework.LeafSystem):
    AddToBuilder: ClassVar[nanobind.nb_func] = ...
    def __init__(self, *args, **kwargs) -> None: ...

class AcrobotInput(pydrake.systems.framework.BasicVector):
    def __init__(self) -> None: ...
    def set_tau(self, arg: float) -> None: ...
    def tau(self) -> float: ...

class AcrobotParams(pydrake.systems.framework.BasicVector):
    def __init__(self) -> None: ...
    def Ic1(self) -> float: ...
    def Ic2(self) -> float: ...
    def b1(self) -> float: ...
    def b2(self) -> float: ...
    def gravity(self) -> float: ...
    def l1(self) -> float: ...
    def lc1(self) -> float: ...
    def lc2(self) -> float: ...
    def m1(self) -> float: ...
    def m2(self) -> float: ...
    def set_Ic1(self, arg: float) -> None: ...
    def set_Ic2(self, arg: float) -> None: ...
    def set_b1(self, arg: float) -> None: ...
    def set_b2(self, arg: float) -> None: ...
    def set_gravity(self, arg: float) -> None: ...
    def set_l1(self, arg: float) -> None: ...
    def set_lc1(self, arg: float) -> None: ...
    def set_lc2(self, arg: float) -> None: ...
    def set_m1(self, arg: float) -> None: ...
    def set_m2(self, arg: float) -> None: ...

class AcrobotPlant(pydrake.systems.framework.LeafSystem):
    get_mutable_state: ClassVar[nanobind.nb_func] = ...
    get_state: ClassVar[nanobind.nb_func] = ...
    def __init__(self) -> None: ...
    def DynamicsBiasTerm(self, *args, **kwargs): ...
    def MassMatrix(self, *args, **kwargs): ...
    def SetMitAcrobotParameters(self, arg: AcrobotParams) -> None: ...
    def get_mutable_parameters(self, context: pydrake.systems.framework.Context) -> AcrobotParams: ...
    def get_parameters(self, context: pydrake.systems.framework.Context) -> AcrobotParams: ...

class AcrobotSpongController(pydrake.systems.framework.LeafSystem):
    def __init__(self) -> None: ...
    def get_mutable_parameters(self, context: pydrake.systems.framework.Context) -> SpongControllerParams: ...
    def get_parameters(self, context: pydrake.systems.framework.Context) -> SpongControllerParams: ...

class AcrobotState(pydrake.systems.framework.BasicVector):
    def __init__(self) -> None: ...
    def set_theta1(self, arg: float) -> None: ...
    def set_theta1dot(self, arg: float) -> None: ...
    def set_theta2(self, arg: float) -> None: ...
    def set_theta2dot(self, arg: float) -> None: ...
    def theta1(self) -> float: ...
    def theta1dot(self) -> float: ...
    def theta2(self) -> float: ...
    def theta2dot(self) -> float: ...

class AcrobotWEncoder(pydrake.systems.framework.Diagram):
    def __init__(self, acrobot_state_as_second_output: bool = ...) -> None: ...
    def acrobot_plant(self) -> AcrobotPlant: ...
    def get_mutable_acrobot_state(self, context: pydrake.systems.framework.Context) -> AcrobotState: ...

class CompassGait(pydrake.systems.framework.LeafSystem):
    def __init__(self) -> None: ...
    def get_floating_base_state_output_port(self) -> pydrake.systems.framework.OutputPort: ...
    def get_minimal_state_output_port(self) -> pydrake.systems.framework.OutputPort: ...

class CompassGaitContinuousState(pydrake.systems.framework.BasicVector):
    def __init__(self) -> None: ...
    def set_stance(self, arg: float) -> None: ...
    def set_stancedot(self, arg: float) -> None: ...
    def set_swing(self, arg: float) -> None: ...
    def set_swingdot(self, arg: float) -> None: ...
    def stance(self) -> float: ...
    def stancedot(self) -> float: ...
    def swing(self) -> float: ...
    def swingdot(self) -> float: ...

class CompassGaitGeometry(pydrake.systems.framework.LeafSystem):
    AddToBuilder: ClassVar[nanobind.nb_func] = ...
    def __init__(self, *args, **kwargs) -> None: ...

class CompassGaitParams(pydrake.systems.framework.BasicVector):
    def __init__(self) -> None: ...
    def center_of_mass_leg(self) -> float: ...
    def gravity(self) -> float: ...
    def length_leg(self) -> float: ...
    def mass_hip(self) -> float: ...
    def mass_leg(self) -> float: ...
    def set_center_of_mass_leg(self, arg: float) -> None: ...
    def set_gravity(self, arg: float) -> None: ...
    def set_length_leg(self, arg: float) -> None: ...
    def set_mass_hip(self, arg: float) -> None: ...
    def set_mass_leg(self, arg: float) -> None: ...
    def set_slope(self, arg: float) -> None: ...
    def slope(self) -> float: ...

class PendulumGeometry(pydrake.systems.framework.LeafSystem):
    AddToBuilder: ClassVar[nanobind.nb_func] = ...
    def __init__(self, *args, **kwargs) -> None: ...

class PendulumInput(pydrake.systems.framework.BasicVector):
    def __init__(self) -> None: ...
    def set_tau(self, tau: float) -> None: ...
    def tau(self) -> float: ...
    def with_tau(self, tau: float) -> PendulumInput: ...

class PendulumParams(pydrake.systems.framework.BasicVector):
    def __init__(self) -> None: ...
    def damping(self) -> float: ...
    def gravity(self) -> float: ...
    def length(self) -> float: ...
    def mass(self) -> float: ...
    def set_damping(self, damping: float) -> None: ...
    def set_gravity(self, gravity: float) -> None: ...
    def set_length(self, length: float) -> None: ...
    def set_mass(self, mass: float) -> None: ...
    def with_damping(self, damping: float) -> PendulumParams: ...
    def with_gravity(self, gravity: float) -> PendulumParams: ...
    def with_length(self, length: float) -> PendulumParams: ...
    def with_mass(self, mass: float) -> PendulumParams: ...

class PendulumPlant(pydrake.systems.framework.LeafSystem):
    get_mutable_state: ClassVar[nanobind.nb_func] = ...
    get_state: ClassVar[nanobind.nb_func] = ...
    def __init__(self) -> None: ...
    def get_mutable_parameters(self, context: pydrake.systems.framework.Context) -> PendulumParams: ...
    def get_parameters(self, context: pydrake.systems.framework.Context) -> PendulumParams: ...
    def get_state_output_port(self) -> pydrake.systems.framework.OutputPort: ...

class PendulumState(pydrake.systems.framework.BasicVector):
    def __init__(self) -> None: ...
    def set_theta(self, theta: float) -> None: ...
    def set_thetadot(self, thetadot: float) -> None: ...
    def theta(self) -> float: ...
    def thetadot(self) -> float: ...
    def with_theta(self, theta: float) -> PendulumState: ...
    def with_thetadot(self, thetadot: float) -> PendulumState: ...

class QuadrotorGeometry(pydrake.systems.framework.LeafSystem):
    AddToBuilder: ClassVar[nanobind.nb_func] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def get_frame_id(self) -> pydrake.geometry.FrameId: ...

class QuadrotorPlant(pydrake.systems.framework.LeafSystem):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, m_arg: float, L_arg: float, I_arg, kF_arg: float, kM_arg: float) -> None: ...
    def force_constant(self) -> float: ...
    def g(self) -> float: ...
    def inertia(self, *args, **kwargs): ...
    def length(self) -> float: ...
    def m(self) -> float: ...
    def moment_constant(self) -> float: ...

class RimlessWheel(pydrake.systems.framework.LeafSystem):
    calc_alpha: ClassVar[nanobind.nb_func] = ...
    def __init__(self) -> None: ...
    def get_floating_base_state_output_port(self) -> pydrake.systems.framework.OutputPort: ...
    def get_minimal_state_output_port(self) -> pydrake.systems.framework.OutputPort: ...

class RimlessWheelContinuousState(pydrake.systems.framework.BasicVector):
    def __init__(self) -> None: ...
    def set_theta(self, arg: float) -> None: ...
    def set_thetadot(self, arg: float) -> None: ...
    def theta(self) -> float: ...
    def thetadot(self) -> float: ...

class RimlessWheelGeometry(pydrake.systems.framework.LeafSystem):
    AddToBuilder: ClassVar[nanobind.nb_func] = ...
    def __init__(self, *args, **kwargs) -> None: ...

class RimlessWheelParams(pydrake.systems.framework.BasicVector):
    def __init__(self) -> None: ...
    def gravity(self) -> float: ...
    def length(self) -> float: ...
    def mass(self) -> float: ...
    def number_of_spokes(self) -> float: ...
    def set_gravity(self, arg: float) -> None: ...
    def set_length(self, arg: float) -> None: ...
    def set_mass(self, arg: float) -> None: ...
    def set_number_of_spokes(self, arg: float) -> None: ...
    def set_slope(self, arg: float) -> None: ...
    def slope(self) -> float: ...

class SpongControllerParams(pydrake.systems.framework.BasicVector):
    def __init__(self) -> None: ...
    def balancing_threshold(self) -> float: ...
    def k_d(self) -> float: ...
    def k_e(self) -> float: ...
    def k_p(self) -> float: ...
    def set_balancing_threshold(self, arg: float) -> None: ...
    def set_k_d(self, arg: float) -> None: ...
    def set_k_e(self, arg: float) -> None: ...
    def set_k_p(self, arg: float) -> None: ...

class VanDerPolOscillator(pydrake.systems.framework.LeafSystem):
    CalcLimitCycle: ClassVar[nanobind.nb_func] = ...
    def __init__(self) -> None: ...
    def get_full_state_output_port(self) -> pydrake.systems.framework.OutputPort: ...
    def get_position_output_port(self) -> pydrake.systems.framework.OutputPort: ...
